<?php

namespace App\Http\Controllers\Admin\Accounts;

use App\Expense;
use App\ExpenseCategory;
use App\Payment;
use App\PaymentTypes;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class ExpenseController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $expense = Expense::orderBy('id', 'desc')->paginate(50);
            return view('admin.accounts.expense.index', compact('expense'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $expense_category = ExpenseCategory::orderBy('id', 'desc')->paginate(50);
            $expense_all = Expense::orderBy('id', 'desc')->paginate(50);
            return view('admin.accounts.expense.create', compact('expense_category', 'expense_all'));
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $this->validate($request, [
                'expense_category_id' => 'required',
                'amount' => 'required',
                'date'  => 'required',
                'payment_type_id'  => 'required',
            ]);
            $requestData = $request->only('created_by_id', 'expense_category_id', 'date', 'amount', 'note', 'status');
            $requestData['created_by_id']=Auth::user()->id;
            $expenseData = Expense::create($requestData);

            // payment
            $paymentData['date']=$expenseData->date;
            $paymentData['created_by_id']=$expenseData->created_by_id;
            $paymentData['client_id']=null;
            $paymentData['invoice_id']=$expenseData->id;
            $paymentData['payment_type_id']=$request->input('payment_type_id');
            $paymentData['payment_category']='Expense-Payment';
            $paymentData['type']='OUT';
            $paymentData['payment_amount']=$request->input('amount');
            $paymentData['payment_note']=$request->input('note');
            if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount'])) {
                $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                if (((isset($balance->incoming_balance)?$balance->incoming_balance:'0')-(isset($balance->outgoing_balance)?$balance->outgoing_balance:'0'))>=$paymentData['payment_amount']) {
                    $payment=Payment::create($paymentData);
                    $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($paymentData['payment_amount']);
                    $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                    $balance->update($paymentTypesDate);
                }else {
                    return redirect()->back()->with('message', 'Insaficient Balance!');
                }
            }
            
            return redirect()->back()->with('message', 'Successfully Expense Submited!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Expense  $expense
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
        //     $expense = Expense::findOrFail($id);
        //     $expense=isset($expense)?$expense->getexpense:null;
        //     return view('admin.accounts.expense.show', compact('expense','expense'));
        // }else{
        //     $permission="'Read Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Expense  $expense
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $expense = Expense::findOrFail($id);
            $expense_category = ExpenseCategory::orderBy('id', 'desc')->paginate(50);
            $expense_all = Expense::orderBy('id', 'desc')->paginate(50);
            return view('admin.accounts.expense.edit', compact('expense', 'expense_category', 'expense_all'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Expense  $expense
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $this->validate($request, [
                'expense_category_id' => 'required',
                'amount' => 'required',
                'date'  => 'required',
            ]);
            $requestData = $request->only('created_by_id', 'expense_category_id');
            $requestData['created_by_id']=Auth::user()->id;
            $expense = Expense::findOrFail($id);
            $expense->update($requestData);

            return redirect()->back()->with('message', 'Successfully Expense Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Expense  $expense
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
        //     Expense::destroy($id);
        //     return redirect('admin/accounts/expense');
        // }else{
        //     $permission="'Delete Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            Expense::whereNotNull('id')->delete();
            return redirect('admin/accounts/expense');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    
}
