<?php

namespace App\Http\Controllers\Admin\Accounts;

use App\Income;
use App\IncomeCategory;
use App\Payment;
use App\PaymentTypes;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class IncomeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $income = Income::orderBy('id', 'desc')->paginate(50);
            return view('admin.accounts.income.index', compact('income'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $income_category = IncomeCategory::orderBy('id', 'desc')->paginate(50);
            $income_all = Income::orderBy('id', 'desc')->paginate(50);
            return view('admin.accounts.income.create', compact('income_category', 'income_all'));
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $this->validate($request, [
                'income_category_id' => 'required',
                'amount' => 'required',
                'date'  => 'required',
                'payment_type_id'  => 'required',
            ]);
            $requestData = $request->only('created_by_id', 'income_category_id', 'date', 'amount', 'note', 'status');
            $requestData['created_by_id']=Auth::user()->id;
            $incomeData = Income::create($requestData);

            // payment
            $paymentData['date']=$incomeData->date;
            $paymentData['created_by_id']=$incomeData->created_by_id;
            $paymentData['client_id']=null;
            $paymentData['invoice_id']=$incomeData->id;
            $paymentData['payment_type_id']=$request->input('payment_type_id');
            $paymentData['payment_category']='Income-Payment';
            $paymentData['type']='IN';
            $paymentData['payment_amount']=$request->input('amount');
            $paymentData['payment_note']=$request->input('note');
            if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount'])) {
                $payment=Payment::create($paymentData);
                $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                $incoming_balance = (isset($balance->incoming_balance)?$balance->incoming_balance:'0')+($paymentData['payment_amount']);
                $paymentTypesDate['incoming_balance'] = $incoming_balance;
                $balance->update($paymentTypesDate);
            }
            
            return redirect()->back()->with('message', 'Successfully income Submited!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Income  $income
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
        //     $income = Income::findOrFail($id);
        //     $income=isset($income)?$income->getincome:null;
        //     return view('admin.accounts.income.show', compact('income','income'));
        // }else{
        //     $permission="'Read Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Income  $income
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $income = Income::findOrFail($id);
            $income_category = IncomeCategory::orderBy('id', 'desc')->paginate(50);
            $income_all = Income::orderBy('id', 'desc')->paginate(50);
            return view('admin.accounts.income.edit', compact('income', 'income_category', 'income_all'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Income  $income
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $this->validate($request, [
                'income_category_id' => 'required',
                'amount' => 'required',
                'date'  => 'required',
            ]);
            $requestData = $request->only('created_by_id', 'income_category_id');
            $requestData['created_by_id']=Auth::user()->id;
            $income = Income::findOrFail($id);
            $income->update($requestData);

            return redirect()->back()->with('message', 'Successfully income Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Income  $income
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
        //     Income::destroy($id);
        //     return redirect('admin/accounts/income');
        // }else{
        //     $permission="'Delete Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            Income::whereNotNull('id')->delete();
            return redirect('admin/accounts/income');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    
}
