<?php

namespace App\Http\Controllers\Admin\Accounts;

use App\PurchaseInvoice;
use App\SaleInvoice;
use App\Payment;
use App\PaymentTypes;
use App\SMS;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class PaymentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
        //     $payment = Payment::orderBy('id', 'desc')->paginate(50);
        //     return view('admin.accounts.payment.index', compact('payment'));
        // }else{
        //     $permission="'Read Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            return view('admin.accounts.payment.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $this->validate($request, [
                'client_id' => 'required',
                'payment_type_id' => 'required',
                'date'  => 'required',
                'type'  => 'required',
            ]);
            // $requestData = $request->all();
            $itemCount = $request->impression;

            // sms template variables
            $smsTemplate=null;

            for ($i=0; $i < $itemCount; $i++) { 
                $paymentData = $request->only('created_by_id', 'client_id', 'payment_type_id', 'invoice_id', 'date', 'type', 'payment_amount', 'payment_note', 'status');
                $paymentData['created_by_id']=Auth::user()->id;
                $paymentData['invoice_id']=$request->input('invoice_id'.$i);
                $paymentData['payment_amount']=$request->input('payment_amount'.$i);
                $paymentData['payment_note']='Invoice # '.$request->input('invoice_id'.$i);
                if (isset($request->type) && isset($paymentData['invoice_id']) && isset($paymentData['payment_amount'])) {
                    if ($request->payment_category == 'Customer-Payment') {
                        $invoice=SaleInvoice::findOrFail($paymentData['invoice_id']);
                        if ($invoice->due>$paymentData['payment_amount']) {
                            $invoiceData['paid']=($invoice->paid)+($paymentData['payment_amount']);
                            $invoiceData['due']=($invoice->due)-($paymentData['payment_amount']);
                            
                            $balance=PaymentTypes::findOrFail($request->payment_type_id);
                            $incoming_balance = (isset($balance->incoming_balance)?$balance->incoming_balance:'0')+($paymentData['payment_amount']);
                            $paymentTypesDate['incoming_balance'] = $incoming_balance;

                            $payment=Payment::create($paymentData);
                            $balance->update($paymentTypesDate);
                            $invoice->update($invoiceData);

                            // sms template
                            $smsTemplate=$smsTemplate.', Ivoice# 000'.$invoice->id.' -> Paid: '.$paymentData['payment_amount'].' BDT, Due: '.$invoiceData['due'];
                        }
                    }elseif ($request->payment_category == 'Supplier-Payment') {
                        $invoice=PurchaseInvoice::findOrFail($paymentData['invoice_id']);
                        if ($invoice->due>$paymentData['payment_amount']) {
                            $invoiceData['paid']=($invoice->paid)+($paymentData['payment_amount']);
                            $invoiceData['due']=($invoice->due)-($paymentData['payment_amount']);
                            
                            $balance=PaymentTypes::findOrFail($request->payment_type_id);
                            if (((isset($balance->incoming_balance)?$balance->incoming_balance:'0')-(isset($balance->outgoing_balance)?$balance->outgoing_balance:'0'))>=$paymentData['payment_amount']) {
                                $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($paymentData['payment_amount']);
                                $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
    
                                $payment=Payment::create($paymentData);
                                $balance->update($paymentTypesDate);
                                $invoice->update($invoiceData);
    
                                // sms template
                                $smsTemplate=$smsTemplate.', Ivoice# 000'.$invoice->id.' -> Paid: '.$paymentData['payment_amount'].' BDT, Due: '.$invoiceData['due'].' BDT';
                            }else {
                                return redirect()->back()->with('message', 'Insaficient Balance!');
                            }
                        }
                    }
                }

            }
            
            //SMS sending section start
            if ($request->sms==1) {
                $smsData['created_by_id']=$payment->created_by_id;
                $smsData['Title']=$request->type;
                $smsData['number']=isset($payment->getClient->phone)?$payment->getClient->phone:'';
                $smsData['message']='Dealer: M/S CloudBari Traders| '.$smsData['Title'].' Completed! '.$smsTemplate;
                $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                if ($smsResult['status']=="SENT") {
                    SMS::create($smsData);
                    return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                }else{
                    return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                }
            }
            //SMS sending section end
            
            return redirect()->back()->with('message', 'Successfully payment completed!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Payment  $payment
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $payment = Payment::findOrFail($id);
            $payment=isset($payment)?$payment->getpayment:null;
            return view('admin.accounts.payment.show', compact('payment','payment'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Payment  $payment
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $payment = Payment::findOrFail($id);
            return view('admin.accounts.payment.edit', compact('payment'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Payment  $payment
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
        //     $this->validate($request, [
        //         'title' => 'required|max:50',
        //     ]);
        //     $requestData = $request->all();
        //     $payment = Payment::findOrFail($id);

        //     $payment->update($requestData);

        //     return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        // }else{
        //     $permission="'Update Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Payment  $payment
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            Payment::destroy($id);
            return redirect('admin/accounts/payment');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            Payment::whereNotNull('id')->delete();
            return redirect('admin/accounts/payment');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function setItem(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->sell==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->accounts)){
            $inputData= array();
            $inputData['client_id']=$_GET['client_id'];
            $inputData['client_type']=$_GET['client_type'];
            switch ($inputData['client_type']) {
                case 'Supplier-Payment':
                    $data = PurchaseInvoice::where('client_id', $inputData['client_id'])
                            ->where('due', '>', 0)->get();
                    return ['setItem'=>$data];
                    break;
                
                case 'Customer-Payment':
                    $data = SaleInvoice::where('client_id', $inputData['client_id'])
                            ->where('due', '>', 0)->get();
                    return ['setItem'=>$data];
                    break;
                
                default:
                    # code...
                    break;
            }
            

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    
}
