<?php

namespace App\Http\Controllers\Admin\HRM;

use App\Employee;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class EmployeeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->hrm)){
            $employee = Employee::all();
            return view('admin.hrm.employee.index', compact('employee'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->hrm)){
            return view('admin.hrm.employee.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->hrm)){
            $this->validate($request, [
                'title' => 'required|max:50',
                'salary' => 'required',
                'salary_type' => 'required',
                'loan' => 'required',
            ]);
            $requestData = $request->all();
            $employee=Employee::create($requestData);

            return redirect()->back()->with('message', 'Successfully Employee Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Employee  $employee
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->hrm)){
        //     $employee = Employee::findOrFail($id);
        //     return view('admin.hrm.employee.show', compact('employee'));
        // }else{
        //     $permission="'Read Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Employee  $employee
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->hrm)){
            $employee = Employee::findOrFail($id);
            return view('admin.hrm.employee.edit', compact('employee'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Employee  $employee
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->hrm)){
            $this->validate($request, [
                'title' => 'required|max:50',
                'salary' => 'required',
                'salary_type' => 'required',
                'loan' => 'required',
            ]);
            $requestData = $request->all();
            $employee = Employee::findOrFail($id);
            $employee->update($requestData);

            return redirect()->back()->with('message', 'Successfully Employee Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Employee  $employee
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->hrm)){
            Employee::destroy($id);
            return redirect('admin/hrm/employee');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->hrm)){
            Employee::whereNotNull('id')->delete();
            return redirect('admin/hrm/employee');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
