<?php

namespace App\Http\Controllers\Admin\InventorySettings;

use App\Badge;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class BadgeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $badge = Badge::all();
            return view('admin.inventorySettings.badge.index', compact('badge'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            return view('admin.inventorySettings.badge.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|unique:badges|max:50',
            ]);
            $requestData = $request->all();
            $requestData['status']=1;
            if ($request->slug==null) {
                $requestData['slug'] = str_slug($request->title);
            }
            Badge::create($requestData);
            return redirect()->back()->with('message', 'Successfully Mordality Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Badge  $badge
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $badge = Badge::findOrFail($id);
            return view('admin.inventorySettings.badge.show', compact('badge'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Badge  $badge
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $badge = Badge::findOrFail($id);
            return view('admin.inventorySettings.badge.edit', compact('badge'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Badge  $badge
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|max:50',
            ]);
            $requestData = $request->all();
            $badge = Badge::findOrFail($id);

            // $requestData['slug'] = str_slug($request->title)."-".uniqid();
            if ($request->slug) {
                $this->validate($request, [
                    'slug' => 'required|unique:badges',
                ]);
                $requestData['slug'] = $request->slug;
            }else{
                $requestData['slug'] = $request->old_slug;
            }
            $badge->update($requestData);

            return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Badge  $badge
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Badge::destroy($id);
            return redirect('admin/inventorySettings/badge');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function badgeStatus(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $badgeStatus = Badge::findOrFail($request->id);
            if($badgeStatus!=null){
                $status['status']=$request->value;
                $badgeStatus->update($status);
            }
            return '1';
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Badge::whereNotNull('id')->delete();
            return redirect('admin/inventorySettings/badge');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
