<?php

namespace App\Http\Controllers\Admin\InventorySettings;

use App\Brand;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class BrandController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $brand = Brand::all();
            return view('admin.inventorySettings.brand.index', compact('brand'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            return view('admin.inventorySettings.brand.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|unique:brands|max:50',
            ]);
            $requestData = $request->all();
            $requestData['status']=1;
            if ($request->slug==null) {
                $requestData['slug'] = str_slug($request->title);
            }
            Brand::create($requestData);
            return redirect()->back()->with('message', 'Successfully Mordality Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Brand  $brand
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $brand = Brand::findOrFail($id);

            return view('admin.inventorySettings.brand.show', compact('brand'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Brand  $brand
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $brand = Brand::findOrFail($id);

            return view('admin.inventorySettings.brand.edit', compact('brand'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Brand  $brand
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|max:50',
            ]);
            $requestData = $request->all();
            $brand = Brand::findOrFail($id);

            // $requestData['slug'] = str_slug($request->title)."-".uniqid();
            if ($request->slug) {
                $this->validate($request, [
                    'slug' => 'required|unique:brands',
                ]);
                $requestData['slug'] = $request->slug;
            }else{
                $requestData['slug'] = $request->old_slug;
            }
            $brand->update($requestData);

            return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Brand  $brand
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Brand::destroy($id);
            return redirect('admin/inventorySettings/brand');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function brandStatus(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $brandStatus = Brand::findOrFail($request->id);
            if($brandStatus!=null){
                $status['status']=$request->value;
                $brandStatus->update($status);
            }
            return '1';
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Brand::whereNotNull('id')->delete();
            return redirect('admin/inventorySettings/brand');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function externalCreateBrand(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $brandData['title']=$_GET['brand_title'];
            $brandData['status']=1;
            $brandData['slug'] = str_slug($brandData['title']);
            $brandExist = Brand::where('title', $brandData['title'])->first();
            
            if (isset($brandExist)) {
                $msg_brand="Brand Exist!";
                $allBrand=null;
                $error="1";
            }else {
                $brand = Brand::create($brandData);
                $allBrand = Brand::where('status', 1)->get();

                $msg_brand="Brand added success!";
                $error="0";
            }

            return ['msg_brand'=>$msg_brand, 
                    'allBrand'=>$allBrand,
                    'error'=>$error];
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
