<?php

namespace App\Http\Controllers\Admin\InventorySettings;

use App\Category;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class CategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $category = Category::all();
            return view('admin.inventorySettings.category.index', compact('category'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            return view('admin.inventorySettings.category.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|unique:categorys|max:50',
            ]);
            $requestData = $request->all();
            $requestData['status']=1;
            if ($request->slug==null) {
                $requestData['slug'] = str_slug($request->title);
            }
            Category::create($requestData);
            return redirect()->back()->with('message', 'Successfully Mordality Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Category  $category
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $category = Category::findOrFail($id);
            return view('admin.inventorySettings.category.show', compact('category'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Category  $category
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $category = Category::findOrFail($id);
            return view('admin.inventorySettings.category.edit', compact('category'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Category  $category
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|max:50',
            ]);
            $requestData = $request->all();
            $category = Category::findOrFail($id);

            // $requestData['slug'] = str_slug($request->title)."-".uniqid();
            if ($request->slug) {
                $this->validate($request, [
                    'slug' => 'required|unique:categorys',
                ]);
                $requestData['slug'] = $request->slug;
            }else{
                $requestData['slug'] = $request->old_slug;
            }
            $category->update($requestData);

            return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Category  $category
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Category::destroy($id);
            return redirect('admin/inventorySettings/category');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function categoryStatus(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $categoryStatus = Category::findOrFail($request->id);
            if($categoryStatus!=null){
                $status['status']=$request->value;
                $categoryStatus->update($status);
            }
            return '1';
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Category::whereNotNull('id')->delete();
            return redirect('admin/inventorySettings/category');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function externalCreateCategory(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $categoryData['title']=$_GET['category_title'];
            $categoryData['status']=1;
            $categoryData['slug'] = str_slug($categoryData['title']);
            $categoryExist = Category::where('title', $categoryData['title'])->first();
            
            if (isset($categoryExist)) {
                $msg_category="Category Exist!";
                $allCategory=null;
                $error="1";
            }else {
                $category = Category::create($categoryData);
                $allCategory = Category::where('status', 1)->get();

                $msg_category="Category added success!";
                $error="0";
            }

            return ['msg_category'=>$msg_category, 
                    'allCategory'=>$allCategory,
                    'error'=>$error];
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
