<?php

namespace App\Http\Controllers\Admin\InventorySettings;

use Auth;
use Image;
use App\Unit;

use App\Product;
use App\Variation;
use App\UserPermission;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Storage;

class ProductController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $product = Product::all();
            return view('admin.inventorySettings.product.index', compact('product'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            return view('admin.inventorySettings.product.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|unique:products|max:50',
            ]);
            $requestData = $request->all();
            $requestData['status']=1;
            if ($request->stock_qty!=null && $request->purchase_value!=null) {
                $requestData['stock_qty'] = $request->stock_qty;
                $requestData['purchase_value'] = $request->purchase_value;
            }

            if ($request->hasFile('image')) {
                $requestData['image'] = $request->file('image')->store('products', 'public');
                $setImage = 'storage/'.$requestData['image'];
                $img_one = Image::make($setImage)->resize(50, 50, function ($constraint) {
                            $constraint->aspectRatio();
                            $constraint->upsize();
                        });
                $img_one->save($setImage);
             }
            $product=Product::create($requestData);

            // variation create
            $variationData['product_id']=$product->id;
            $variationData['unit_id']=$request->unit_id;
            $variationData['qty']=$request->qty;
            $variationData['unit_of_qty_id']=$request->unit_of_qty_id;
            if (isset($variationData['qty']) && isset($variationData['unit_id']) && $variationData['qty']>0) {
                $unit=Unit::findOrFail($request->unit_id);
                $variationData['title']=isset($unit)?$unit->title:'Other';
                $variation=Variation::create($variationData);
            }

            return redirect()->back()->with('message', 'Successfully Mordality Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $product = Product::findOrFail($id);
            $variation=isset($product->getVariation)?$product->getVariation:null;
            return view('admin.inventorySettings.product.show', compact('product', 'variation'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $product = Product::findOrFail($id);
            return view('admin.inventorySettings.product.edit', compact('product'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|max:50',
            ]);
            $requestData = $request->all();
            $product = Product::findOrFail($id);
            if ($request->stock_qty!=null && $request->purchase_value!=null) {
                $requestData['stock_qty'] = (isset($product->stock_qty)?$product->stock_qty:'0')+$request->stock_qty;
                $requestData['purchase_value'] = (isset($product->purchase_value)?$product->purchase_value:'0')+$request->purchase_value;
            }else{
                $requestData['stock_qty'] = $product->stock_qty;
                $requestData['purchase_value'] = $product->purchase_value;
            }

            if ($request->hasFile('image')) {
                if (!$request->old_image='') {
                    Storage::delete('public/' . $product->image);
                }

                $requestData['image'] = $request->file('image')->store('products', 'public');
                $setImage = 'storage/'.$requestData['image'];
                
                $img_one = Image::make($setImage)->resize(50, 50, function ($constraint) {
                            $constraint->aspectRatio();
                            $constraint->upsize();
                        });
                $img_one->save($setImage);
            }else{
                $requestData['image'] = $request->old_image;
            }
            
            $product->update($requestData);

            return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $product = Product::findOrFail($id);
            if ($product->image!=null) {
                Storage::delete('public/' . $product->image);
            }
            Product::destroy($id);
            return redirect('admin/inventorySettings/product');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function productStatus(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $productStatus = Product::findOrFail($request->id);
            if($productStatus!=null){
                $status['status']=$request->value;
                $productStatus->update($status);
            }
            return '1';
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $product = Product::all();
            foreach ($product as $item) {
                if ($item->image!=null) {
                    Storage::delete('public/' . $item->image);
                }
            }
            Product::whereNotNull('id')->delete();
            return redirect('admin/inventorySettings/product');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

}
