<?php

namespace App\Http\Controllers\Admin\InventorySettings;

use App\Unit;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class UnitController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $unit = Unit::all();
            return view('admin.inventorySettings.unit.index', compact('unit'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            return view('admin.inventorySettings.unit.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|unique:units|max:50',
            ]);
            $requestData = $request->all();
            $requestData['status']=1;
            if ($request->slug==null) {
                $requestData['slug'] = str_slug($request->title);
            }
            Unit::create($requestData);
            return redirect()->back()->with('message', 'Successfully Mordality Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Unit  $unit
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $unit = Unit::findOrFail($id);
            return view('admin.inventorySettings.unit.show', compact('unit'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Unit  $unit
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $unit = Unit::findOrFail($id);
            return view('admin.inventorySettings.unit.edit', compact('unit'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Unit  $unit
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'title' => 'required|max:50',
            ]);
            $requestData = $request->all();
            $unit = Unit::findOrFail($id);

            // $requestData['slug'] = str_slug($request->title)."-".uniqid();
            if ($request->slug) {
                $this->validate($request, [
                    'slug' => 'required|unique:units',
                ]);
                $requestData['slug'] = $request->slug;
            }else{
                $requestData['slug'] = $request->old_slug;
            }
            $unit->update($requestData);

            return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Unit  $unit
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Unit::destroy($id);
            return redirect('admin/inventorySettings/unit');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function unitStatus(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $unitStatus = Unit::findOrFail($request->id);
            if($unitStatus!=null){
                $status['status']=$request->value;
                $unitStatus->update($status);
            }
            return '1';
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Unit::whereNotNull('id')->delete();
            return redirect('admin/inventorySettings/unit');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function externalCreateUnit(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $unitData['title']=$_GET['unit_title'];
            $unitData['status']=1;
            $unitData['slug'] = str_slug($unitData['title']);
            $unitExist = Unit::where('title', $unitData['title'])->first();
            
            if (isset($unitExist)) {
                $msg_unit="Unit Exist!";
                $allUnit=null;
                $error="1";
            }else {
                $unit = Unit::create($unitData);
                $allUnit = Unit::where('status', 1)->get();

                $msg_unit="Unit added success!";
                $error="0";
            }

            return ['msg_unit'=>$msg_unit, 
                    'allUnit'=>$allUnit,
                    'error'=>$error];
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
