<?php

namespace App\Http\Controllers\Admin\InventorySettings;

use App\Variation;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Unit;
use Auth;
use App\UserPermission;

class VariationController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $variation = Variation::all();
            return view('admin.inventorySettings.variation.index', compact('variation'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            return view('admin.inventorySettings.variation.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'product_id' => 'required',
            ]);
            if (isset($request->variationImpression)) {
                // variation
                $variationCount = $request->variationImpression;
                $variationData['product_id']=$request->product_id;
                for ($i=1; $i <= $variationCount; $i++){
                    $variationData['unit_id']=$request->input('unit_id'.$i);
                    $variationData['qty']=$request->input('qty'.$i);
                    $variationData['unit_of_qty_id']=$request->input('unit_of_qty_id'.$i);
                    if (isset($variationData['qty']) && isset($variationData['unit_id']) && $variationData['qty']>0) {
                        $unit=Unit::findOrFail($request->input('unit_id'.$i));
                        $variationData['title']=isset($unit)?$unit->title:'Other';
                        $variation=Variation::create($variationData);
                    }
                }
            }else {
                $requestData = $request->all();
                Variation::create($requestData);
            }
            return redirect()->back()->with('message', 'Successfully Variation Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Variation  $variation
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $variation = Variation::findOrFail($id);
            return view('admin.inventorySettings.variation.show', compact('variation'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Variation  $variation
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $variation = Variation::findOrFail($id);
            return view('admin.inventorySettings.variation.edit', compact('variation'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Variation  $variation
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            $this->validate($request, [
                'product_id' => 'required',
            ]);
            $requestData = $request->all();
            $variation = Variation::findOrFail($id);

            $variation->update($requestData);

            return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Variation  $variation
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Variation::destroy($id);
            return redirect('admin/inventorySettings/variation');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->inventory)){
            Variation::whereNotNull('id')->delete();
            return redirect('admin/inventorySettings/variation');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
