<?php

namespace App\Http\Controllers\Admin\PurchaseRegisters;

use DB;
use Auth;
use App\SMS;
use App\Client;
use App\Expense;
use App\Payment;
use App\Product;
use App\Purchase;
use App\Variation;
use App\Accounting;
use App\PaymentTypes;
use App\ClientBalance;
use App\UserPermission;

use App\PurchaseInvoice;
use App\StockUpdateRecord;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;

class PurchaseController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchaseInvoice = PurchaseInvoice::orderBy('id', 'desc')->paginate(200);
            return view('admin.purchaseRegisters.purchase.index', compact('purchaseInvoice'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            return view('admin.purchaseRegisters.purchase.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $this->validate($request, [
                'client_id' => 'required',
                'date' => 'required',
                'subTotal' => 'required',
                'payable' => 'required',
                'paid' => 'required',
            ]);
            // $requestData = $request->all();
            $purchaseInvoiceData = $request->only('created_by_id', 'client_id', 'date', 'phone', 'subTotal', 'vat', 'vatType', 'discount', 'discountType', 'discountNote', 'shipment', 'advance', 'payable', 'paid', 'due', 'note', 'status', 'labour_cost');
            $purchaseInvoiceData['created_by_id']=Auth::user()->id;
            $purchaseInvoiceData['due']=$purchaseInvoiceData['payable']-$purchaseInvoiceData['paid'];
            $purchaseInvoiceClientData=Client::findOrFail($purchaseInvoiceData['client_id']);
            $purchaseInvoiceData['old_balance']=($purchaseInvoiceClientData->balance)-($purchaseInvoiceClientData->due);
            $purchaseInvoice=PurchaseInvoice::create($purchaseInvoiceData);

            $itemCount = $request->impression;
            for ($i=1; $i <= $itemCount; $i++) {
                $purchaseData = $request->only('client_id', 'date', 'note', 'status');
                $purchaseData['created_by_id']=$purchaseInvoiceData['created_by_id'];
                $purchaseData['purchase_invoice_id']=$purchaseInvoice->id;
                $purchaseData['product_id']=$request->input('product_id'.$i);
                $purchaseData['unit_id']=$request->input('unit_id'.$i);
                $purchaseData['rate']=$request->input('rate'.$i);
                $purchaseData['parUnitQty']=$request->input('parUnitQty'.$i);
                $purchaseData['qty']=$request->input('qty'.$i);
                $purchaseData['discount']=$request->input('itemDiscount'.$i);
                $purchaseData['discountType']=$request->input('itemDiscountType'.$i);
                $purchaseData['total']=$request->input('total'.$i);
                if (isset($purchaseData['product_id']) && isset($purchaseData['total'])) {
                    $product=Product::findOrFail($purchaseData['product_id']);
                    $purchaseData['category_id'] = $product->category_id;
                    $purchaseData['invoiceRate']=$product->purchase_price;
                    $purchaseData['status']=0;
                    $purchase=Purchase::create($purchaseData);
                    // $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')+$purchaseData['qty'];
                    // $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')+$purchaseData['total'];
                    // $product->update($productData);

                }
                // dd($purchaseData);
            }

            // payment
            $paymentCount = $request->paymentImpression;
            for ($i=1; $i <= $paymentCount; $i++){
                $paymentData['date']=$purchaseInvoice->date;
                $paymentData['created_by_id']=$purchaseInvoice->created_by_id;
                $paymentData['client_id']=$purchaseInvoice->client_id;
                $paymentData['invoice_id']=$purchaseInvoice->id;
                $paymentData['payment_type_id']=$request->input('payment_type_id'.$i);
                $paymentData['payment_category']='Supplier-Payment';
                $paymentData['type']='OUT';
                $paymentData['payment_amount']=$request->input('payment_amount'.$i);
                $paymentData['payment_note']='Purchase INV-'.$purchaseInvoice->id.' '.$request->input('payment_note'.$i);
                if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount']) && $paymentData['payment_amount']>0) {
                    $payment=Payment::create($paymentData);
                    $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                    $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($paymentData['payment_amount']);
                    $paymentTypesData['outgoing_balance'] = $outgoing_balance;
                    $balance->update($paymentTypesData);
                }
            }

            // expense shipment payment
            $expenseShipmentData['created_by_id']=Auth::user()->id;
            $expenseShipmentData['expense_category_id']=11;
            $expenseShipmentData['date']=$purchaseInvoice->date;
            $expenseShipmentData['amount']=$request->input('shipment_amount');
            $expenseShipmentData['note']='Purchase Invoice No. '.$purchaseInvoice->id;
            $expenseShipmentData['ref_id']=$purchaseInvoice->id;
            $expenseShipmentData['prefix']='Purchase';
            $expenseData = Expense::create($expenseShipmentData);
            $expensePaymentData['date']=$expenseData->date;
            $expensePaymentData['created_by_id']=$expenseData->created_by_id;
            $expensePaymentData['client_id']=null;
            $expensePaymentData['invoice_id']=$expenseData->id;
            $expensePaymentData['payment_type_id']=$request->input('shipment_payment_type_id');
            $expensePaymentData['payment_category']='Expense-Payment';
            $expensePaymentData['type']='OUT';
            $expensePaymentData['payment_amount']=$request->input('shipment_amount');
            if (isset($expensePaymentData['payment_type_id']) && isset($expensePaymentData['payment_amount']) && $expensePaymentData['payment_amount']>0) {
                $balance=PaymentTypes::findOrFail($expensePaymentData['payment_type_id']);
                $payment=Payment::create($expensePaymentData);
                $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($expensePaymentData['payment_amount']);
                $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                $balance->update($paymentTypesDate);
            }
            // expense labour payment
            $expenseLabourData['created_by_id']=Auth::user()->id;
            $expenseLabourData['expense_category_id']=6;
            $expenseLabourData['date']=$purchaseInvoice->date;
            $expenseLabourData['amount']=$request->input('labour_amount');
            $expenseLabourData['note']='Purchase Invoice No. '.$purchaseInvoice->id;
            $expenseShipmentData['ref_id']=$purchaseInvoice->id;
            $expenseShipmentData['prefix']='Purchase';
            $expenseData = Expense::create($expenseLabourData);
            $expensePaymentData['date']=$expenseData->date;
            $expensePaymentData['created_by_id']=$expenseData->created_by_id;
            $expensePaymentData['client_id']=null;
            $expensePaymentData['invoice_id']=$expenseData->id;
            $expensePaymentData['payment_type_id']=$request->input('labour_payment_type_id');
            $expensePaymentData['payment_category']='Expense-Payment';
            $expensePaymentData['type']='OUT';
            $expensePaymentData['payment_amount']=$request->input('labour_amount');
            if (isset($expensePaymentData['payment_type_id']) && isset($expensePaymentData['payment_amount']) && $expensePaymentData['payment_amount']>0) {
                $balance=PaymentTypes::findOrFail($expensePaymentData['payment_type_id']);
                $payment=Payment::create($expensePaymentData);
                $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($expensePaymentData['payment_amount']);
                $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                $balance->update($paymentTypesDate);
            }

            //client balance calculate
            $client=Client::findOrFail($purchaseInvoice->client_id);
            $advance_paid=$purchaseInvoice->advance;
            $balance=(isset($client->balance)?$client->balance:'0')-($advance_paid);
            $due=(isset($client->due)?$client->due:'0')+$purchaseInvoiceData['due'];
            if ($balance>$due) {
                $clientDate['balance']=$balance-$due;
                $clientDate['due']=0;
            }else {
                $clientDate['balance']=0;
                $clientDate['due']=$due-$balance;
            }
            $client->update($clientDate);

            //accounting record
            $accountingData['created_by_id']=$purchaseInvoice->created_by_id;
            $accountingData['client_id']=$purchaseInvoice->client_id;
            $accountingData['ref_id']=$purchaseInvoice->id;
            $accountingData['date']=$purchaseInvoice->date;
            $accountingData['debit']=$purchaseInvoice->paid; // paid
            $accountingData['credit']=($purchaseInvoice->subTotal); //payable
            $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
            $accountingData['description']='Purchase';
            $accountingData['note']=$purchaseInvoice->note;
            $accounting=Accounting::create($accountingData);

            //SMS sending section start
            if ($request->sms==1) {
                $smsData['created_by_id']=$purchaseInvoice->created_by_id;
                $smsData['Title']='Purchase Item';
                $smsData['number']=isset($purchaseInvoice->getClient->phone)?$purchaseInvoice->getClient->phone:'';
                $totalBalance=isset($purchaseInvoice->getClient->balance)?$purchaseInvoice->getClient->balance:'0';
                $totalDue=isset($purchaseInvoice->getClient->due)?$purchaseInvoice->getClient->due:'0';
                $invoiceWiseTotal = ($purchaseInvoice->payable)+($purchaseInvoice->advance);
                $advanceAndPaid = ($purchaseInvoice->paid)+($purchaseInvoice->advance);
                $smsData['message']='Dealer: M/S CloudBari Traders, Purchase Completed! Supplier Name: '.$client->title.'. Invoice Number/Ref: '.$purchaseInvoice->id.', Invoice wise total: '.$invoiceWiseTotal.'BDT, Old Due'.$client->due.' BDT, Advance/Paid: '.$advanceAndPaid.' BDT, Total current balance: '.$totalBalance.' BDT, Total due balance: '.$totalDue.' BDT, Date: '.$purchaseData['date'];
                $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                if ($smsResult['status']=="SENT") {
                    SMS::create($smsData);
                    // return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                }else{
                    return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                }
            }
            //SMS sending section end

            if ($request->printOn==1) {
                $purchase=isset($purchaseInvoice->getPurchase)?$purchaseInvoice->getPurchase:null;
                return view('admin.purchaseRegisters.purchase.show', compact('purchaseInvoice','purchase'));
            }else{
                return redirect()->back()->with('message', 'Successfully Purchase completed!');
            }
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Purchase  $purchase
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchaseInvoice = PurchaseInvoice::findOrFail($id);
            $purchase=isset($purchaseInvoice->getPurchase)?$purchaseInvoice->getPurchase:null;
            return view('admin.purchaseRegisters.purchase.show', compact('purchaseInvoice','purchase'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Purchase  $purchase
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchase = Purchase::findOrFail($id);
            return view('admin.purchaseRegisters.purchase.edit', compact('purchase'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Purchase  $purchase
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
        //     $this->validate($request, [
        //         'title' => 'required|max:50',
        //     ]);
        //     $requestData = $request->all();
        //     $purchase = Purchase::findOrFail($id);

        //     $purchase->update($requestData);

        //     return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        // }else{
        //     $permission="'Update Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Purchase  $purchase
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchaseInvoice = PurchaseInvoice::findOrFail($id);
            $purchase=isset($purchaseInvoice->getPurchase)?$purchaseInvoice->getPurchase:null;
            foreach ($purchase as $item) {
                $product=Product::findOrFail($item->product_id);
                $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')-($item->collection);
                $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')-(($item->collection)*($item->rate));
                $product->update($productData);
            }

            $payment = Payment::where('invoice_id', $id)->where('payment_category', 'Supplier-Payment')->get();
            foreach ($payment as $item) {
                $balance=PaymentTypes::findOrFail($item->payment_type_id);
                $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')-($item->payment_amount);
                $paymentTypesData['outgoing_balance'] = $outgoing_balance;
                $balance->update($paymentTypesData);
            }

            //client balance calculate
            $client=Client::findOrFail($purchaseInvoice->client_id);
            $advance_paid=$purchaseInvoice->advance;
            $balance=(isset($client->balance)?$client->balance:'0')+($advance_paid);
            $due=(isset($client->due)?$client->due:'0')-$purchaseInvoice->due;
            if ($balance>$due) {
                $clientDate['balance']=$balance-$due;
                $clientDate['due']=0;
            }else {
                $clientDate['balance']=0;
                $clientDate['due']=$due-$balance;
            }
            $client->update($clientDate);

            // expense
            $expense = Expense::where('ref_id', $id)->where('prefix', 'Purchase')->get();
            foreach ($expense as $item) {
                $expensePayment = Payment::where('invoice_id', $item->id)->where('payment_category', 'Expense-Payment')->first();
                if (isset($expensePayment)) {
                    $balance=PaymentTypes::findOrFail($expensePayment->payment_type_id);
                    $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')-($expensePayment->payment_amount);
                    $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                    $balance->update($paymentTypesDate);
                    $expensePayment->delete();
                }
            }

            $accounting = Accounting::where('ref_id', $id)->where('description', 'Purchase')->delete();

            $purchase->each->delete();
            $payment->each->delete();
            $expense->each->delete();
            PurchaseInvoice::destroy($id);
            return redirect('admin/purchaseRegisters/purchase');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            PurchaseInvoice::whereNotNull('id')->delete();
            Purchase::whereNotNull('id')->delete();
            return redirect('admin/purchaseRegisters/purchase');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function advanceSearchIndex(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $requestData = $request;
            $dbQuery = PurchaseInvoice::query();
            if ($request->client_id!='') {
                $dbQuery->where('client_id', $request->client_id);
            }
            if ($request->invoice_id!='') {
                $dbQuery->where('id', $request->invoice_id);
            }
            $purchaseInvoice = $dbQuery->get();
            return view('admin.purchaseRegisters.purchase.index', compact('purchaseInvoice'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }

    public function setItem(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $inputData= array();
            $inputData['product_id']=$_GET['product_id'];
            $inputData['unit_id']=$_GET['unit_id'];
            $data = Product::findOrFail($inputData['product_id']);
            $dataVariation = isset($data->getVariation)?$data->getVariation:null;
            $price='';
            $variationparUnitQty='';
            $unitOption=isset($data->getUnit)?$data->getUnit:null;
            $single=true;
            $variation=null;
            if (count($dataVariation)>0) {
                $unitOption=$dataVariation;
                $single=false;
            }
            if ($inputData['unit_id'] && $dataVariation) {
                $variation=$dataVariation->where('product_id', $inputData['product_id'])
                    ->where('unit_id', $inputData['unit_id'])->first();
                $purchase_price=isset($data->purchase_price)?$data->purchase_price:'0';
                $qty=$data->qty;
                $variationQty=isset($variation->qty)?$variation->qty:'0';
                $price=($purchase_price/$qty)*$variationQty;
            }
            if (isset($variation->qty)) {
                $variationparUnitQty=$variation->qty;
            }else {
                $variationparUnitQty=null;
            }
            return ['setItem'=>$data, 'variation'=>$variation,'variationPrice'=>$price, 'variationparUnitQty'=>$variationparUnitQty, 'unitOption'=>$unitOption, 'single'=>$single];

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function setClientData(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $inputData= array();
            $inputData['client_id']=$_GET['client_id'];
            $data = Client::findOrFail($inputData['client_id']);
            return ['setClientData'=>$data];
        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function setItemBarcode(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $inputData= array();
            $inputData['code']=$_GET['code'];
            $data = Product::where('code', $inputData['code'])->first();
            $dataVariation = isset($data->getVariation)?$data->getVariation:null;
            $unitOption=isset($data->getUnit)?$data->getUnit:null;
            $single=true;
            if (count($dataVariation)>0) {
                $unitOption=$dataVariation;
                $single=false;
            }
            return ['setItem'=>$data, 'unitOption'=>$unitOption, 'single'=>$single];

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    public function setItemProductId(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $inputData= array();
            $inputData['product_id']=$_GET['product_id'];
            $data = Product::where('id', $inputData['product_id'])->first();
            $dataVariation = isset($data->getVariation)?$data->getVariation:null;
            $unitOption=isset($data->getUnit)?$data->getUnit:null;
            $single=true;
            if (count($dataVariation)>0) {
                $unitOption=$dataVariation;
                $single=false;
            }
            return ['setItem'=>$data, 'unitOption'=>$unitOption, 'single'=>$single];

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    // due Invoice
    public function dueClient()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $dueClient = Client::where('type', 'supplier')->whereNotNull('due')->where('due', '>', '0')->orderBy('id', 'desc')->paginate(50);
            return view('admin.purchaseRegisters.purchase.dueClient', compact('dueClient'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }
    public function dueClientPaid()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $clientBalanceData['created_by_id']=Auth::user()->id;
            $clientBalanceData['client_id']=$_GET['client_id'];
            $clientBalanceData['payment_type_id']=$_GET['payment_type_id'];
            $clientBalanceData['date']=$_GET['date'];
            $clientBalanceData['amount']=$_GET['amount'];
            $clientBalanceData['note']=$_GET['note'];
            $clientBalanceData['type']='IN';
            $balanceClient=Client::findOrFail($clientBalanceData['client_id']);
            $clientBalanceData['old_balance'] = $balanceClient->balance;
            $clientBalanceData['old_due'] = $balanceClient->due;
            // return ['data'=>'Paid'];
            $clientBalance = ClientBalance::create($clientBalanceData);

            // payment
            $paymentData['date']=$clientBalanceData['date'];
            $paymentData['created_by_id']=$clientBalanceData['created_by_id'];
            $paymentData['client_id']=$clientBalanceData['client_id'];
            $paymentData['payment_type_id']=$clientBalanceData['payment_type_id'];
            $paymentData['payment_amount']=$clientBalanceData['amount'];
            $paymentData['payment_note']='ClientBalance CB-'.$clientBalanceData['note'];
            if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount']) && $paymentData['payment_amount']>0) {
                $balance=(isset($balanceClient->balance)?$balanceClient->balance:'0')+($paymentData['payment_amount']);
                $due=isset($balanceClient->due)?$balanceClient->due:'0';
                if ($balance>$due) {
                    $balanceClientData['balance']=$balance-$due;
                    $balanceClientData['due']=0;
                }else {
                    $balanceClientData['balance']=0;
                    $balanceClientData['due']=$due-$balance;
                }
                $balanceClient->update($balanceClientData);

                $paymentData['payment_category']='Supplier-Payment';
                $paymentData['type']='OUT';
                $payment=Payment::create($paymentData);

                $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($paymentData['payment_amount']);
                $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                $balance->update($paymentTypesDate);

                //accounting record
                $accountingData['created_by_id']=$payment->created_by_id;
                $accountingData['client_id']=$payment->client_id;
                $accountingData['ref_id']=$payment->id;
                $accountingData['date']=$payment->date;
                $accountingData['debit']=$payment->payment_amount; //payable
                $accountingData['credit']=0; // paid
                $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
                $accountingData['description']='Supplier-Payment';
                $accountingData['note']=$payment->payment_note;
                $accounting=Accounting::create($accountingData);
                //SMS sending section start
                $sms = $_GET['sms'];
                $smsStatus=null;
                if ($sms=='true') {
                    $smsData['created_by_id']=$clientBalance->created_by_id;
                    $smsData['number']=isset($clientBalance->getClient->phone)?$clientBalance->getClient->phone:'';
                    $smsTemplateClient=isset($clientBalanceData->getClient->title)?$clientBalanceData->getClient->title:null;
                    $smsData['message']='Dealer: M/S CloudBari Traders, Make due payment to '.$smsTemplateClient.'. Old Due'.$balanceClient->due.'BDT, Paid: '.$clientBalance->amount.' BDT, Total due balance:: '.$balanceClientData['due'].' BDT, Total current balance: '.$balanceClientData['balance'].' BDT, Date: '.$clientBalanceData['date'];
                    $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                    if ($smsResult['status']=="SENT") {
                        SMS::create($smsData);
                    }
                    $smsStatus=$smsResult['status'].' '.$smsResult['statusmsg'];
                }
                //SMS sending section end

            }

            return ['data'=>'Paid', 'balance'=>$balanceClientData['balance'], 'due'=>$balanceClientData['due'], 'smsStatus'=>$smsStatus];
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }
    // due Invoice end
    
    // due Invoice
    public function stockUpdate()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $stockUpdate = Purchase::whereRaw('COALESCE(collection, 0) < ?', ['qty'])->where('status', 0)->orderBy('id', 'desc')->paginate(50);
            return view('admin.purchaseRegisters.purchase.stockUpdate', compact('stockUpdate'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }
    public function stockUpdateRecord()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $stockUpdateData['created_by_id']=Auth::user()->id;
            $stockUpdateData['purchase_id']=$_GET['purchase_id'];
            $stockUpdateData['purchase_invoice_id']=$_GET['purchase_invoice_id'];
            $stockUpdateData['product_id']=$_GET['product_id'];
            $stockUpdateData['unit_of_qty_id']=$_GET['unit_of_qty_id'];
            $stockUpdateData['payment_type_id']=$_GET['payment_type_id'];
            $stockUpdateData['date']=$_GET['date'];
            $stockUpdateData['old_stock']=$_GET['old_stock'];
            $stockUpdateData['qty']=$_GET['qty'];
            $stockUpdateData['flag']=$_GET['flag'];
            $stockUpdateData['shipment']=$_GET['shipment'];
            $stockUpdateData['labour_cost']=$_GET['labour_cost'];
            $purchase = Purchase::findOrFail($stockUpdateData['purchase_id']);
            $collection=isset($purchase->collection)?$purchase->collection:0;
            $return_qty=isset($purchase->return_qty)?$purchase->return_qty:0;
            $collectNow=$_GET['collectNow'];
            $stockUpdateData['collection']=$collectNow;
            $totalColection=$collection+$collectNow;
            $resColection=($collection-$return_qty)+$collectNow;
            $currentStock=$stockUpdateData['old_stock']+$collectNow;
            $rate=($_GET['rate'])/($_GET['parUnitQty']);
            $stockUpdateData['purchase_value']=($rate)*($collectNow);
            $purchaseData['collection']=$totalColection;
            // Stock Update------------
            $product=Product::findOrFail($stockUpdateData['product_id']);
            $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')+$collectNow;
            $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')+(($rate)*($collectNow));
            
            if ($resColection==$stockUpdateData['qty']) {
                $stockUpdateData['status']=1;
                $purchaseData['status']=1;
                $btn="Updated";
                $purchase->update($purchaseData);
                $product->update($productData);
                $stockUpdate = StockUpdateRecord::create($stockUpdateData);
            }elseif ($resColection<$stockUpdateData['qty']) {
                $stockUpdateData['status']=0;
                $purchaseData['status']=0;
                $btn="Updated";
                $purchase->update($purchaseData);
                $product->update($productData);
                $stockUpdate = StockUpdateRecord::create($stockUpdateData);
            }else {
                $btn="Try Again";
            }


            // expense shipment payment
            $expenseShipmentData['created_by_id']=Auth::user()->id;
            $expenseShipmentData['expense_category_id']=11;
            $expenseShipmentData['date']=$stockUpdateData['date'];
            $expenseShipmentData['amount']=$stockUpdateData['shipment'];
            $expenseShipmentData['note']='Purchase Invoice No. '.$stockUpdateData['purchase_invoice_id'];
            $expenseShipmentData['ref_id']=$stockUpdateData['purchase_invoice_id'];
            $expenseShipmentData['prefix']='Purchase';
            if ($expenseShipmentData['amount']>0) {
                $expenseData = Expense::create($expenseShipmentData);
            }
            $expensePaymentData['date']=$expenseShipmentData['date'];
            $expensePaymentData['created_by_id']=$expenseShipmentData['created_by_id'];
            $expensePaymentData['client_id']=null;
            $expensePaymentData['invoice_id']=isset($expenseData)?$expenseData->id:null;
            $expensePaymentData['payment_type_id']=$stockUpdateData['payment_type_id'];
            $expensePaymentData['payment_category']='Expense-Payment';
            $expensePaymentData['type']='OUT';
            $expensePaymentData['payment_amount']=$stockUpdateData['shipment'];
            if (isset($expensePaymentData['payment_type_id']) && isset($expensePaymentData['payment_amount']) && $expensePaymentData['payment_amount']>0) {
                $balance=PaymentTypes::findOrFail($expensePaymentData['payment_type_id']);
                $payment=Payment::create($expensePaymentData);
                $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($expensePaymentData['payment_amount']);
                $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                $balance->update($paymentTypesDate);
            }
            // expense shipment payment end

            // expense labour payment
            $expenseLabourData['created_by_id']=Auth::user()->id;
            $expenseLabourData['expense_category_id']=6;
            $expenseLabourData['date']=$stockUpdateData['date'];
            $expenseLabourData['amount']=$stockUpdateData['labour_cost'];
            $expenseLabourData['note']='Purchase Invoice No. '.$stockUpdateData['purchase_invoice_id'];
            $expenseShipmentData['ref_id']=$stockUpdateData['purchase_invoice_id'];
            $expenseShipmentData['prefix']='Purchase';
            if ($expenseLabourData['amount']>0) {
                $expenseData = Expense::create($expenseLabourData);
            }
            $expensePaymentData['date']=$expenseLabourData['date'];
            $expensePaymentData['created_by_id']=$expenseLabourData['created_by_id'];
            $expensePaymentData['client_id']=null;
            $expensePaymentData['invoice_id']=isset($expenseData)?$expenseData->id:null;
            $expensePaymentData['payment_type_id']=$stockUpdateData['payment_type_id'];
            $expensePaymentData['payment_category']='Expense-Payment';
            $expensePaymentData['type']='OUT';
            $expensePaymentData['payment_amount']=$stockUpdateData['labour_cost'];
            if (isset($expensePaymentData['payment_type_id']) && isset($expensePaymentData['payment_amount']) && $expensePaymentData['payment_amount']>0) {
                $balance=PaymentTypes::findOrFail($expensePaymentData['payment_type_id']);
                $payment=Payment::create($expensePaymentData);
                $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($expensePaymentData['payment_amount']);
                $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                $balance->update($paymentTypesDate);
            }
            // expense labour payment end


            return ['btn'=>$btn, 
                'current_stock'=>$currentStock, 
                'collection'=>$resColection];
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }
    public function stockUpdateComplete()
    {
        if(Auth::user()->getRole->admin==1 && Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchase_id=$_GET['purchase_id'];
            $passwordData['pass']=$_GET['pass'];
            $purchase = Purchase::findOrFail($purchase_id);
            $password = Hash::check($passwordData['pass'], Auth::user()->password);
            if ($password==true) {
                $purchaseData['status']=1;
                $purchase->update($purchaseData);
                $btn="Complete";
                $success_msg="Purchase Completed!";
            }else {
                $btn="Try Again";
                $success_msg="Wrong Password!";
            }
            return ['btn'=>$btn, 'success_msg'=>$success_msg];
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }
    // due Invoice end

    // public function payment()
    // {
    //     if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
    //         return view('admin.purchaseRegisters.purchase.form.payment');
    //     }else{
    //         $permission="'Create Level' permission needed!!!";
    //         return view('admin.notify.permission_denied', compact('permission'));
    //     }
    // }

    public function return($purchase_invoice_id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchaseInvoice = PurchaseInvoice::findOrFail($purchase_invoice_id);
            $purchase = isset($purchaseInvoice->getPurchase)?$purchaseInvoice->getPurchase:null;
            return view('admin.purchaseRegisters.return.create', compact('purchaseInvoice', 'purchase'));
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
