<?php

namespace App\Http\Controllers\Admin\PurchaseRegisters;

use App\PurchaseReturn;
use App\PurchaseReturnInvoice;
use App\PurchaseInvoice;
use App\Purchase;
use App\Variation;
use App\Product;
use App\Payment;
use App\PaymentTypes;
use App\Client;
use App\Accounting;
use App\Expense;
use App\SMS;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class PurchaseReturnController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchaseReturnInvoice = PurchaseReturnInvoice::orderBy('id', 'desc')->paginate(50);
            return view('admin.purchaseRegisters.return.index', compact('purchaseReturnInvoice'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            return view('admin.purchaseRegisters.return.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $this->validate($request, [
                'purchase_invoice_id' => 'required',
                'date' => 'required',
                'payable' => 'required',
            ]);
            // $requestData = $request->all();

            $purchaseReturnInvoiceData = $request->only('created_by_id', 'purchase_invoice_id', 'date', 'subTotal', 'shipment', 'payable', 'paid', 'due', 'note', 'status', 'labour_cost');
            $purchaseReturnInvoiceData['created_by_id']=Auth::user()->id;
            $addBalance=$purchaseReturnInvoiceData['payable']-$purchaseReturnInvoiceData['paid'];
            $purchaseInvoice=PurchaseInvoice::findOrFail($request->purchase_invoice_id);
            $purchaseReturnInvoiceClientData=Client::findOrFail(isset($purchaseInvoice->client_id)?$purchaseInvoice->client_id:'0');
            $purchaseReturnInvoiceData['old_balance']=($purchaseReturnInvoiceClientData->balance)-($purchaseReturnInvoiceClientData->due);
            $purchaseReturnInvoiceData['client_id']=isset($purchaseInvoice->client_id)?$purchaseInvoice->client_id:null;

            //purchase invoice update
            $purchaseInvoiceData['return_amount']=(isset($purchaseInvoice->return_amount)?$purchaseInvoice->return_amount:'0')+($request->subTotal);
            if ($purchaseInvoiceData['return_amount']>0 && $purchaseInvoiceData['return_amount']<=$purchaseInvoice->subTotal) {
                $purchaseReturnInvoice=purchaseReturnInvoice::create($purchaseReturnInvoiceData);
                $purchaseInvoice->update($purchaseInvoiceData);

                $itemCount = $request->impression;
                for ($i=0; $i <= $itemCount; $i++) {
                    $purchaseReturnData = $request->only('date', 'note', 'status');
                    $purchaseReturnData['created_by_id']=$purchaseReturnInvoiceData['created_by_id'];
                    $purchaseReturnData['purchase_return_invoice_id']=$purchaseReturnInvoice->id;
                    $purchaseReturnData['purchase_item_id']=$request->input('purchase_item_id'.$i);
                    $purchaseReturnData['client_id']=$purchaseReturnInvoice->client_id;
                    $purchaseReturnData['product_id']=$request->input('product_id'.$i);
                    $purchaseReturnData['unit_id']=$request->input('unit_id'.$i);
                    $purchaseReturnData['rate']=$request->input('rate'.$i);
                    $purchaseReturnData['parUnitQty']=$request->input('parUnitQty'.$i);
                    $purchaseReturnData['qty']=$request->input('qty'.$i);
                    $purchaseReturnData['discount']=$request->input('itemDiscount'.$i);
                    $purchaseReturnData['discountType']=$request->input('itemDiscountType'.$i);
                    $purchaseReturnData['total']=$request->input('total'.$i);
                    if($purchaseReturnData['purchase_item_id']!=null){
                        $purchaseItem=Purchase::findOrFail($purchaseReturnData['purchase_item_id']);
                        $purchase_pre_total=isset($purchaseItem->total)?$purchaseItem->total:'0';
                        $returnQty=isset($purchaseItem->return_qty)?$purchaseItem->return_qty:'0';
                        $totalReturnQty=($returnQty)+($purchaseReturnData['qty']);
                        if ($totalReturnQty>$purchaseItem->collection) {
                            $totalReturnQty=$purchaseItem->collection;
                        }
                    }

                    if (isset($purchaseReturnData['product_id']) && isset($purchaseReturnData['total']) && $request->input('qty'.$i) && ($request->input('qty'.$i))>0 && $purchase_pre_total>=$purchaseReturnData['total']) {
                        $product=Product::findOrFail($purchaseReturnData['product_id']);
                        $purchaseReturnData['category_id'] = $product->category_id;
                        $purchaseReturn=PurchaseReturn::create($purchaseReturnData);

                        // stock update
                        if ($purchaseItem->collection>$returnQty) {
                            
                            if ($totalReturnQty>$purchaseItem->collection) {
                                $decreaseStockQty=($purchaseItem->collection)-$returnQty;
                            }else{
                                $decreaseStockQty = (($returnQty+$purchaseReturnData['qty']) > ($purchaseItem->collection)) ? ($purchaseItem->collection) - ($returnQty) : ($returnQty) - ($purchaseReturnData['qty']);
                            }
                            $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')-$decreaseStockQty;
                            $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')-($purchaseReturnData['rate']*$decreaseStockQty);
                            $product->update($productData);
                        }

                        // purchase item update
                        if($purchaseReturnData['purchase_item_id']!=null){
                            $purchaseData['return_amount'] = (isset($purchaseItem->return_amount)?$purchaseItem->return_amount:'0')+$purchaseReturnData['total'];
                            $purchaseData['return_qty'] = $totalReturnQty;
                            $purchaseItem->update($purchaseData);
                        }

                    }
                    // dd($purchaseReturnData);
                }

                // payment
                $paymentCount = $request->paymentImpression;
                for ($i=1; $i <= $paymentCount; $i++){
                    $paymentData['date']=$purchaseReturnInvoice->date;
                    $paymentData['created_by_id']=$purchaseReturnInvoice->created_by_id;
                    $paymentData['client_id']=$purchaseReturnInvoice->client_id;
                    $paymentData['invoice_id']=$purchaseReturnInvoice->id;
                    $paymentData['payment_type_id']=$request->input('payment_type_id'.$i);
                    $paymentData['payment_category']='Supplier-Payment-Return';
                    $paymentData['type']='IN';
                    $paymentData['payment_amount']=$request->input('payment_amount'.$i);
                    $paymentData['payment_note']='PR-000'.$purchaseReturnInvoice->id.' '.$request->input('payment_note'.$i);
                    if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount']) && $paymentData['payment_amount']>0) {
                        $payment=Payment::create($paymentData);
                        $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                        $incoming_balance = (isset($balance->incoming_balance)?$balance->incoming_balance:'0')+($paymentData['payment_amount']);
                        $paymentTypesData['incoming_balance'] = $incoming_balance;
                        $balance->update($paymentTypesData);
                    }
                }

                // expense shipment payment
                $expenseShipmentData['created_by_id']=Auth::user()->id;
                $expenseShipmentData['expense_category_id']=11;
                $expenseShipmentData['date']=$purchaseInvoice->date;
                $expenseShipmentData['amount']=$request->input('shipment_amount');
                $expenseShipmentData['note']='Purchase Return Invoice No. '.$purchaseReturnInvoice->id;
                $expenseShipmentData['ref_id']=$purchaseReturnInvoice->id;
                $expenseShipmentData['prefix']='Purchase-Return';
                $expenseData = Expense::create($expenseShipmentData);
                $expensePaymentData['date']=$expenseData->date;
                $expensePaymentData['created_by_id']=$expenseData->created_by_id;
                $expensePaymentData['client_id']=null;
                $expensePaymentData['invoice_id']=$expenseData->id;
                $expensePaymentData['payment_type_id']=$request->input('shipment_payment_type_id');
                $expensePaymentData['payment_category']='Expense-Payment';
                $expensePaymentData['type']='OUT';
                $expensePaymentData['payment_amount']=$request->input('shipment_amount');
                if (isset($expensePaymentData['payment_type_id']) && isset($expensePaymentData['payment_amount']) && $expensePaymentData['payment_amount']>0) {
                    $balance=PaymentTypes::findOrFail($expensePaymentData['payment_type_id']);
                    $payment=Payment::create($expensePaymentData);
                    $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($expensePaymentData['payment_amount']);
                    $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                    $balance->update($paymentTypesDate);
                }
                // expense labour payment
                $expenseLabourData['created_by_id']=Auth::user()->id;
                $expenseLabourData['expense_category_id']=6;
                $expenseLabourData['date']=$purchaseInvoice->date;
                $expenseLabourData['amount']=$request->input('labour_amount');
                $expenseLabourData['note']='Purchase Return Invoice No. '.$purchaseReturnInvoice->id;
                $expenseLabourData['ref_id']=$purchaseReturnInvoice->id;
                $expenseLabourData['prefix']='Purchase-Return';
                $expenseData = Expense::create($expenseLabourData);
                $expensePaymentData['date']=$expenseData->date;
                $expensePaymentData['created_by_id']=$expenseData->created_by_id;
                $expensePaymentData['client_id']=null;
                $expensePaymentData['invoice_id']=$expenseData->id;
                $expensePaymentData['payment_type_id']=$request->input('labour_payment_type_id');
                $expensePaymentData['payment_category']='Expense-Payment';
                $expensePaymentData['type']='OUT';
                $expensePaymentData['payment_amount']=$request->input('labour_amount');
                if (isset($expensePaymentData['payment_type_id']) && isset($expensePaymentData['payment_amount']) && $expensePaymentData['payment_amount']>0) {
                    $balance=PaymentTypes::findOrFail($expensePaymentData['payment_type_id']);
                    $payment=Payment::create($expensePaymentData);
                    $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($expensePaymentData['payment_amount']);
                    $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                    $balance->update($paymentTypesDate);
                }

                //client balance calculate
                $client=Client::findOrFail($purchaseInvoice->client_id);
                $balance=(isset($client->balance)?$client->balance:'0')+($addBalance);
                $due=(isset($client->due)?$client->due:'0')-$request->due;
                if ($balance>$due) {
                    $clientDate['balance']=$balance-$due;
                    $clientDate['due']=0;
                }else {
                    $clientDate['balance']=0;
                    $clientDate['due']=$due-$balance;
                }
                $client->update($clientDate);

                //accounting record
                $accountingData['created_by_id']=$purchaseReturnInvoice->created_by_id;
                $accountingData['client_id']=$purchaseReturnInvoice->client_id;
                $accountingData['ref_id']=$purchaseReturnInvoice->id;
                $accountingData['date']=$purchaseReturnInvoice->date;
                $accountingData['debit']=($purchaseReturnInvoice->subTotal); //payable
                $accountingData['credit']=$purchaseReturnInvoice->paid; // paid
                $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
                $accountingData['description']='Purchase-Return';
                $accountingData['note']=$purchaseReturnInvoice->note;
                $accounting=Accounting::create($accountingData);

                //SMS sending section start
                if ($request->sms==1) {
                    $smsData['created_by_id']=$purchaseReturnInvoice->created_by_id;
                    $smsData['Title']='Return Purchase';
                    $smsData['number']=isset($purchaseReturnInvoice->getClient->phone)?$purchaseReturnInvoice->getClient->phone:'';
                    $totalBalance=isset($purchaseReturnInvoice->getClient->balance)?$purchaseReturnInvoice->getClient->balance:'0';
                    $totalDue=isset($purchaseReturnInvoice->getClient->due)?$purchaseReturnInvoice->getClient->due:'0';
                    $smsData['message']='Dealer: M/S CloudBari Traders, Purchase Return Completed! Return Invoice Number/Ref'.$purchaseReturnInvoice->id.', Invoice wise return total: '.$purchaseReturnInvoice->return_amount.' BDT, Old Due: '.$client->due.' BDT, Paid: '.$purchaseReturnInvoice->paid.' BDT, Total current balance: '.$totalBalance.' BDT, Total due balance: '.$totalDue.' BDT, Date: '.$purchaseReturnInvoiceData['date'];
                    $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                    if ($smsResult['status']=="SENT") {
                        SMS::create($smsData);
                        // return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                    }else{
                        return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                    }
                }
                //SMS sending section end


                if ($request->printOn==1) {
                    $purchaseReturn=isset($purchaseReturnInvoice->getPurchaseReturn)?$purchaseReturnInvoice->getPurchaseReturn:null;
                    return view('admin.purchaseRegisters.return.show', compact('purchaseReturnInvoice','purchaseReturn'));
                }else{
                    return redirect()->back()->with('message', 'Successfully Purchase Return completed!');
                }
            }else {
                return redirect()->back()->with('message', 'faild');
            }

        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\PurchaseReturn  $purchase
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchaseReturnInvoice = PurchaseReturnInvoice::findOrFail($id);
            $purchaseReturn=isset($purchaseReturnInvoice->getPurchaseReturn)?$purchaseReturnInvoice->getPurchaseReturn:null;
            return view('admin.purchaseRegisters.return.show', compact('purchaseReturnInvoice','purchaseReturn'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\PurchaseReturn  $purchase
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchaseReturn = PurchaseReturn::findOrFail($id);
            return view('admin.purchaseRegisters.return.edit', compact('purchaseReturn'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\PurchaseReturn  $purchase
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
        //     $this->validate($request, [
        //         'title' => 'required|max:50',
        //     ]);
        //     $requestData = $request->all();
        //     $purchaseReturn = PurchaseReturn::findOrFail($id);

        //     $purchaseReturn->update($requestData);

        //     return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        // }else{
        //     $permission="'Update Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\PurchaseReturn  $purchase
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $purchaseReturnInvoice = PurchaseReturnInvoice::findOrFail($id);
            $purchaseReturn=isset($purchaseReturnInvoice->getPurchaseReturn)?$purchaseReturnInvoice->getPurchaseReturn:null;

            // purchase item update
            foreach ($purchaseReturn as $item) {
                $purchaseItem=Purchase::findOrFail($item->purchase_item_id);
                $purchaseData['return_amount'] = (isset($purchaseItem->return_amount)?$purchaseItem->return_amount:'0')-($item->total);
                $purchaseItem->update($purchaseData);

                //product update
                $product=Product::findOrFail($item->product_id);
                $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')+($item->qty);
                $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')+($item->total);
                $product->update($productData);
            }

            //Purchase invoice update
            $purchaseInvoice=PurchaseInvoice::findOrFail($purchaseReturnInvoice->purchase_invoice_id);
            $purchaseInvoiceData['return_amount']=(isset($purchaseInvoice->return_amount)?$purchaseInvoice->return_amount:'0')-($purchaseReturnInvoice->subTotal);
            $purchaseInvoice->update($purchaseInvoiceData);

            $payment = Payment::where('invoice_id', $id)->where('payment_category', 'Supplier-Payment-Return')->get();
            foreach ($payment as $item) {
                $balance=PaymentTypes::findOrFail($item->payment_type_id);
                $incoming_balance = (isset($balance->incoming_balance)?$balance->incoming_balance:'0')-($item->payment_amount);
                $paymentTypesData['incoming_balance'] = $incoming_balance;
                $balance->update($paymentTypesData);
            }

            //client balance calculate
            $client=Client::findOrFail($purchaseReturnInvoice->client_id);
            $addBalance=($purchaseReturnInvoice->payable)-($purchaseReturnInvoice->paid);
            $balance=(isset($client->balance)?$client->balance:'0')-($addBalance);
            $due=(isset($client->due)?$client->due:'0')+($purchaseReturnInvoice->due);
            if ($balance>$due) {
                $clientDate['balance']=$balance-$due;
                $clientDate['due']=0;
            }else {
                $clientDate['balance']=0;
                $clientDate['due']=$due-$balance;
            }
            $client->update($clientDate);

            // expense
            $expense = Expense::where('ref_id', $id)->where('prefix', 'Purchase-Return')->get();
            foreach ($expense as $item) {
                $expensePayment = Payment::where('invoice_id', $item->id)->where('payment_category', 'Expense-Payment')->first();
                if (isset($expensePayment)) {
                    $balance=PaymentTypes::findOrFail($expensePayment->payment_type_id);
                    $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')-($expensePayment->payment_amount);
                    $paymentTypesDate['outgoing_balance'] = $outgoing_balance;
                    $balance->update($paymentTypesDate);
                    $expensePayment->delete();
                }
            }

            $accounting = Accounting::where('ref_id', $id)->where('description', 'Purchase-Return')->delete();
            $purchaseReturn->each->delete();
            $payment->each->delete();
            $expense->each->delete();
            PurchaseReturnInvoice::destroy($id);
            return redirect('admin/purchaseRegisters/return');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            PurchaseReturnInvoice::whereNotNull('id')->delete();
            return redirect('admin/purchaseRegisters/return');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function setItem(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->purchase_section)){
            $inputData= array();
            $inputData['purchase_invoice_id']=$_GET['purchase_invoice_id'];
            $data = PurchaseInvoice::findOrFail($inputData['purchase_invoice_id']);
            $data2 = isset($data->getPurchase)?$data->getPurchase:null;
            $data3 = isset($data->getClient)?$data->getClient:null;
            return ['setItem'=>$data, 'setItemPurchase'=>$data2, 'setClient'=>$data3];

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
