<?php

namespace App\Http\Controllers\Admin\Registers;

use App\Client;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Accounting;
use Auth;
use App\UserPermission;

class ClientController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            $client = Client::all();
            return view('admin.registers.client.index', compact('client'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            return view('admin.registers.client.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            $this->validate($request, [
                'title' => 'required|unique:clients|max:50',
                'type' => 'required',
                'opening_date' => 'required',
            ]);
            $requestData = $request->all();
            $requestData['status']=1;
            $balance=isset($request->opening_balance)?$request->opening_balance:'0';
            $due=isset($request->opening_due)?$request->opening_due:'0';
            if ($balance>$due) {
                $requestData['balance']=$balance-$due;
                $requestData['due']=0;
            }else {
                $requestData['balance']=0;
                $requestData['due']=$due-$balance;
            }
            $client=Client::create($requestData);

            //accounting record
            $accountingData['created_by_id']=null;
            $accountingData['client_id']=$client->id;
            $accountingData['ref_id']=$client->id;
            $accountingData['date']=isset($client->opening_date)?$client->opening_date:date("Y-m-d");
            $accountingData['debit']=$requestData['balance']; // paid
            $accountingData['credit']=$requestData['due']; //payable
            $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
            $accountingData['description']='Opening-Balance';
            $accountingData['note']=null;
            $accounting=Accounting::create($accountingData);

            return redirect()->back()->with('message', 'Successfully Mordality Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Client  $client
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            $client = Client::findOrFail($id);
            return view('admin.registers.client.show', compact('client'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Client  $client
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            $client = Client::findOrFail($id);
            return view('admin.registers.client.edit', compact('client'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Client  $client
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            $this->validate($request, [
                'title' => 'required|max:50',
                'type' => 'required',
            ]);
            $requestData = $request->all();
            $client = Client::findOrFail($id);
            
            $opening_balance=(isset($client->opening_balance)?$client->opening_balance:'0')+(isset($request->opening_balance)?$request->opening_balance:'0');
            $opening_due=(isset($client->opening_due)?$client->opening_due:'0')+(isset($request->opening_due)?$request->opening_due:'0');
            $balance=(isset($client->balance)?$client->balance:'0')+(isset($request->opening_balance)?$request->opening_balance:'0');
            $due=(isset($client->due)?$client->due:'0')+(isset($request->opening_due)?$request->opening_due:'0');
            if ($balance>$due) {
                $requestData['balance']=$balance-$due;
                $requestData['due']=0;
            }else {
                $requestData['balance']=0;
                $requestData['due']=$due-$balance;
            }
            $requestData['opening_balance']=$opening_balance;
            $requestData['opening_due']=$opening_due;
            $client->update($requestData);

            //accounting record
            $accounting = Accounting::where('client_id', $id)->where('ref_id', $id)->where('description', 'Opening-Balance')->first();
            if ($request->opening_date!='') {
                $accountingData['date']=$request->opening_date;
            }
            $accountingData['debit']=$opening_balance; // paid
            $accountingData['credit']=$opening_due; //payable
            $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
            if (isset($accounting)) {
                $accounting->update($accountingData);
            }

            return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Client  $client
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            Client::destroy($id);
            return redirect('admin/registers/client');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function clientStatus(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            $clientStatus = Client::findOrFail($request->id);
            if($clientStatus!=null){
                $status['status']=$request->value;
                $clientStatus->update($status);
            }
            return '1';
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            Client::whereNotNull('id')->delete();
            return redirect('admin/registers/client');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    
    public function externalCreateClient(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->register)){
            $clientData['title']=$_GET['client_title'];
            $clientData['type']=$_GET['client_type'];
            $clientData['opening_date']=$_GET['client_opening_date'];
            $clientData['address']=$_GET['client_address'];
            $clientData['phone']=$_GET['client_phone'];
            $clientData['opening_balance']=$_GET['client_opening_balance'];
            $clientData['opening_due']=$_GET['client_opening_due'];
            $balance=isset($clientData['opening_balance'])?$clientData['opening_balance']:'0';
            $due=isset($clientData['opening_due'])?$clientData['opening_due']:'0';
            $clientData['status']=1;
            if ($balance>$due) {
                $clientData['balance']=$balance-$due;
                $clientData['due']=0;
            }else {
                $clientData['balance']=0;
                $clientData['due']=$due-$balance;
            }
            $clientExist = Client::where('title', $clientData['title'])->first();
            
            if (isset($clientExist)) {
                $msg="Client Exist!";
                $allClients=null;
                $error="1";
            }else {
                $client = Client::create($clientData);
                $allClients = Client::where('type', $clientData['type'])->get();

                //accounting record
                $accountingData['created_by_id']=null;
                $accountingData['client_id']=$client->id;
                $accountingData['ref_id']=$client->id;
                $accountingData['date']=isset($client->opening_date)?$client->opening_date:date("Y-m-d");
                $accountingData['debit']=$clientData['balance']; // paid
                $accountingData['credit']=$clientData['due']; //payable
                $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
                $accountingData['description']='Opening-Balance';
                $accountingData['note']=null;
                $accounting=Accounting::create($accountingData);

                $msg="Client added success!";
                $error="0";
            }

            return ['msg'=>$msg, 
                    'allClients'=>$allClients,
                    'error'=>$error];
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }


}
