<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Role;
use App\User;
use Illuminate\Http\Request;
use Auth;
use App\UserPermission;

class RoleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $role = Role::where('id', '>=', '2')->get();
            return view('admin.role.index', compact('role'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            return view('admin.role.create');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $this->validate($request, [
                'title' => 'required|max:50',
            ]);
            $requestData = $request->all();
            Role::create($requestData);
            return redirect()->back()->with('message', 'Successfully Create Role!');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Role  $role
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $role = Role::findOrFail($id);
            return view('admin.role.show', compact('role'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Role  $role
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $role = Role::findOrFail($id);
            return view('admin.role.edit', compact('role'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Role  $role
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $this->validate($request, [
                'title' => 'required|max:50',
            ]);
            $requestData = $request->all();
            if($request->create==null){
                $requestData['create']=$request->create;
            }
            if($request->read==null){
                $requestData['read']=$request->read;
            }
            if($request->update==null){
                $requestData['update']=$request->update;
            }
            if($request->delete==null){
                $requestData['delete']=$request->delete;
            }
            if($request->sell==null){
                $requestData['sell']=$request->sell;
            }
            if($request->admin==null){
                $requestData['admin']=$request->admin;
            }
            if($request->email==null){
                $requestData['email']=$request->email;
            }
            $role = Role::findOrFail($id);
            $role->update($requestData);

            return redirect()->back()->with('message', 'Successfully Update Role!');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Role  $role
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            if ($id!=1 && $id!=2 && $id!=3 && $id!=4) {
                Role::destroy($id);
                return redirect()->back()->with('message', 'Role deleted!');
            }else{
                return redirect()->back()->with('message', 'Default Role can not delete!');
            }
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
