<?php

namespace App\Http\Controllers\Admin\SaleRegisters;

use App\Sale;
use App\SaleInvoice;
use App\OrderSale;
use App\OrderSaleInvoice;
use App\Product;
use App\Payment;
use App\PaymentTypes;
use App\Variation;
use App\SMS;
use App\Client;
use App\Accounting;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class OrderSaleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            $orderSaleInvoice = OrderSaleInvoice::whereNull('status')->orderBy('id', 'desc')->paginate(200);
            return view('admin.saleRegisters.order_sale.index', compact('orderSaleInvoice'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            return view('admin.saleRegisters.order_sale.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            $this->validate($request, [
                'client_id' => 'required',
                'date' => 'required',
                'subTotal' => 'required',
                'payable' => 'required',
                'paid' => 'required',
            ]);
            // $requestData = $request->all();

            $orderSaleInvoiceData = $request->only('created_by_id', 'client_id', 'reference_id', 'date', 'phone', 'subTotal', 'vat', 'vatType', 'discount', 'discountType', 'discountNote', 'coupon', 'shipment', 'advance', 'payable', 'paid', 'due', 'note', 'status', 'labour_cost');
            $orderSaleInvoiceData['created_by_id']=Auth::user()->id;
            $orderSaleInvoiceData['due']=$orderSaleInvoiceData['payable']-$orderSaleInvoiceData['paid'];
            $orderSaleInvoice=OrderSaleInvoice::create($orderSaleInvoiceData);

            $itemCount = $request->impression;
            for ($i=1; $i <= $itemCount; $i++) {
                $saleData = $request->only('client_id', 'date', 'note', 'status');
                $saleData['created_by_id']=$orderSaleInvoiceData['created_by_id'];
                $saleData['order_sale_invoice_id']=$orderSaleInvoice->id;
                $saleData['product_id']=$request->input('product_id'.$i);
                $saleData['badge_id']=$request->input('badge_id'.$i);
                $saleData['type']=$request->input('type'.$i);
                $saleData['unit_id']=$request->input('unit_id'.$i);
                $saleData['rate']=$request->input('rate'.$i);
                $saleData['parUnitQty']=$request->input('parUnitQty'.$i);
                $saleData['qty']=$request->input('qty'.$i);
                $saleData['discount']=$request->input('itemDiscount'.$i);
                $saleData['discountType']=$request->input('itemDiscountType'.$i);
                $saleData['total']=$request->input('total'.$i);
                if (isset($saleData['product_id']) && isset($saleData['total'])) {
                    $product=Product::findOrFail($saleData['product_id']);
                    $saleData['category_id'] = $product->category_id;
                    $saleData['lessable_qty']=$saleData['qty'];
                    $orderSale=OrderSale::create($saleData);
                }
            }

            //SMS sending section start
            if ($request->sms==1) {
                $smsData['created_by_id']=$orderSaleInvoice->created_by_id;
                $smsData['Title']='Sale Item';
                if (isset($saleInvoice->phone)) {
                    $smsData['number']=isset($orderSaleInvoice->phone)?$orderSaleInvoice->phone:'';
                }else{
                    $smsData['number']=isset($orderSaleInvoice->getClient->phone)?$orderSaleInvoice->getClient->phone:'';
                }
                $clientTitle=isset($orderSaleInvoice->getClient->title)?$orderSaleInvoice->getClient->title:null;
                $totalBalance=isset($orderSaleInvoice->getClient->balance)?$orderSaleInvoice->getClient->balance:'0';
                $totalDue=isset($orderSaleInvoice->getClient->due)?$orderSaleInvoice->getClient->due:'0';
                $smsData['message']='Dealer: M/S CloudBari Traders, Sale Completed! Customer Name: '.$clientTitle.'. Order Number/Ref: '.$orderSaleInvoice->id.', Invoice wise total: '.$orderSaleInvoice->subTotal.' BDT, Total current balance : '.$totalBalance.' BDT, Total due balance : '.$totalDue.' BDT, Date: '.$orderSaleInvoiceData['date'];
                $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                if ($smsResult['status']=="SENT") {
                    SMS::create($smsData);
                    // return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                }else{
                    return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                }
            }
            //SMS sending section end

            return redirect()->back()->with('message', 'Successfully Sale completed!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Sale  $sale
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            $orderSaleInvoice = OrderSaleInvoice::findOrFail($id);
            $orderSale=isset($orderSaleInvoice)?$orderSaleInvoice->getOrderSale:null;
            return view('admin.saleRegisters.order_sale.show', compact('orderSaleInvoice','orderSale'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Sale  $sale
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            $orderSaleInvoice = OrderSaleInvoice::findOrFail($id);
            $orderSale = isset($orderSaleInvoice->getOrderSale)?$orderSaleInvoice->getOrderSale:null;
            return view('admin.saleRegisters.order_sale.edit', compact('orderSale', 'orderSaleInvoice'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Sale  $sale
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){

            if ($request->confirmOn==1 && Auth::user()->getRole->admin==1) {
                $this->validate($request, [
                    'client_id' => 'required',
                    'date' => 'required',
                    'subTotal' => 'required',
                    'payable' => 'required',
                    'paid' => 'required',
                ]);

                $saleInvoiceData = $request->only('created_by_id', 'client_id', 'reference_id', 'date', 'phone', 'subTotal', 'vat', 'vatType', 'discount', 'discountType', 'discountNote', 'coupon', 'shipment', 'advance', 'payable', 'paid', 'due', 'note', 'status', 'labour_cost');
                $saleInvoiceData['created_by_id']=Auth::user()->id;
                $saleInvoiceData['due']=$saleInvoiceData['payable']-$saleInvoiceData['paid'];
                $saleInvoiceClientData=Client::findOrFail($saleInvoiceData['client_id']);
                $saleInvoiceData['old_balance']=($saleInvoiceClientData->balance)-($saleInvoiceClientData->due);
                $saleInvoice=SaleInvoice::create($saleInvoiceData);

                $itemCount = $request->impression;
                for ($i=1; $i <= $itemCount; $i++) {
                    $saleData = $request->only('client_id', 'date', 'note', 'status');
                    $saleData['created_by_id']=$saleInvoiceData['created_by_id'];
                    $saleData['sale_invoice_id']=$saleInvoice->id;
                    $saleData['product_id']=$request->input('product_id'.$i);
                    $saleData['badge_id']=$request->input('badge_id'.$i);
                    $saleData['type']=$request->input('type'.$i);
                    $saleData['unit_id']=$request->input('unit_id'.$i);
                    $saleData['rate']=$request->input('rate'.$i);
                    $saleData['parUnitQty']=$request->input('parUnitQty'.$i);
                    $saleData['qty']=$request->input('qty'.$i);
                    $saleData['discount']=$request->input('itemDiscount'.$i);
                    $saleData['discountType']=$request->input('itemDiscountType'.$i);
                    $saleData['total']=$request->input('total'.$i);
                    if (isset($saleData['product_id']) && isset($saleData['total']) && isset($saleData['qty']) && $saleData['qty']!=0) {
                        $product=Product::findOrFail($saleData['product_id']);
                        $productPurchase=($product->purchase_value)/(isset($product->stock_qty)?$product->stock_qty:'1');
                        // $productQty=$product->qty;
                        $purchase_value=$productPurchase*$saleData['qty'];
                        $saleData['purchase_value']=$purchase_value;
                        $saleData['category_id'] = $product->category_id;
                        $sale=Sale::create($saleData);
                        $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')-$saleData['qty'];
                        $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')-$purchase_value;
                        $product->update($productData);

                    }
                }

                // order sales status change
                $orderSaleInvoice = OrderSaleInvoice::findOrFail($id);
                $orderSaleInvoiceData['status']='1';
                $orderSaleInvoice->update($orderSaleInvoiceData);

                // payment
                $paymentCount = $request->paymentImpression;
                for ($i=1; $i <= $paymentCount; $i++){
                    $paymentData['date']=$saleInvoice->date;
                    $paymentData['created_by_id']=$saleInvoice->created_by_id;
                    $paymentData['client_id']=$saleInvoice->client_id;
                    $paymentData['invoice_id']=$saleInvoice->id;
                    $paymentData['payment_type_id']=$request->input('payment_type_id'.$i);
                    $paymentData['payment_category']='Customer-Payment';
                    $paymentData['type']='IN';
                    $paymentData['payment_amount']=$request->input('payment_amount'.$i);
                    $paymentData['payment_note']='Sales INV-'.$saleInvoice->id.' '.$request->input('payment_note'.$i);

                    if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount']) && $paymentData['payment_amount']>0) {
                        $payment=Payment::create($paymentData);
                        $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                        $incoming_balance = (isset($balance->incoming_balance)?$balance->incoming_balance:'0')+($paymentData['payment_amount']);
                        $paymentTypesData['incoming_balance'] = $incoming_balance;
                        $balance->update($paymentTypesData);
                    }
                }

                //client balance calculate
                $client=Client::findOrFail($saleInvoice->client_id);
                $advance_paid=$saleInvoice->advance;
                $balance=(isset($client->balance)?$client->balance:'0')-($advance_paid);
                $due=(isset($client->due)?$client->due:'0')+$saleInvoiceData['due'];
                if ($balance>$due) {
                    $clientDate['balance']=$balance-$due;
                    $clientDate['due']=0;
                }else {
                    $clientDate['balance']=0;
                    $clientDate['due']=$due-$balance;
                }
                $client->update($clientDate);

                //accounting record
                $accountingData['created_by_id']=$saleInvoice->created_by_id;
                $accountingData['client_id']=$saleInvoice->client_id;
                $accountingData['ref_id']=$saleInvoice->id;
                $accountingData['date']=$saleInvoice->date;
                $accountingData['debit']=$saleInvoice->paid; // paid
                // $accountingData['credit']=($saleInvoice->payable); //payable
                $accountingData['credit']=($saleInvoice->subTotal)+($saleInvoice->shipment)+($saleInvoice->labour_cost); //sales amount
                $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
                $accountingData['description']='Sales';
                $accountingData['note']=$saleInvoice->note;
                $accounting=Accounting::create($accountingData);

                //SMS sending section start
                if ($request->sms==1) {
                    $smsData['created_by_id']=$saleInvoice->created_by_id;
                    $smsData['Title']='Sale Item';
                    if (isset($saleInvoice->phone)) {
                        $smsData['number']=isset($saleInvoice->phone)?$saleInvoice->phone:'';
                    }else{
                        $smsData['number']=isset($saleInvoice->getClient->phone)?$saleInvoice->getClient->phone:'';
                    }
                    $totalBalance=isset($saleInvoice->getClient->balance)?$saleInvoice->getClient->balance:'0';
                    $totalDue=isset($saleInvoice->getClient->due)?$saleInvoice->getClient->due:'0';
                    $invoiceWiseTotal = ($saleInvoice->payable)+($saleInvoice->advance);
                    $advanceAndPaid = ($saleInvoice->paid)+($saleInvoice->advance);
                    $smsData['message']='Dealer: M/S CloudBari Traders, Sale Completed! Customer Name'.$client->title.' Invoice number/ref: '.$saleInvoice->id.', Invoice wise total: '.$invoiceWiseTotal.' BDT, Old Due: '.$client->due.' BTD, Advance/Paid: '.$advanceAndPaid.' BDT, Total current balance : '.$totalBalance.' BDT, Total due balance : '.$totalDue.' BDT, Date: '.$saleInvoiceData['date'];
                    $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                    if ($smsResult['status']=="SENT") {
                        SMS::create($smsData);
                        // return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                    }else{
                        return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                    }
                }
                //SMS sending section end

                //redirect to order sale index page
                $orderSaleInvoice = OrderSaleInvoice::whereNull('status')->orderBy('id', 'desc')->paginate(50);
                return view('admin.saleRegisters.order_sale.index', compact('orderSaleInvoice'));
            }else{
                $this->validate($request, [
                    'client_id' => 'required',
                    'date' => 'required',
                    'subTotal' => 'required',
                    'payable' => 'required',
                    'paid' => 'required',
                ]);
                // $requestData = $request->all();
                $orderSaleInvoice = OrderSaleInvoice::findOrFail($id);
                $saleInvoiceData = $request->only('created_by_id', 'client_id', 'reference_id', 'date', 'phone', 'subTotal', 'vat', 'vatType', 'discount', 'discountType', 'discountNote', 'coupon', 'shipment', 'payable', 'paid', 'due', 'note', 'status', 'labour_cost');
                $saleInvoiceData['created_by_id']=Auth::user()->id;
                $saleInvoiceData['due']=$saleInvoiceData['payable']-$saleInvoiceData['paid'];
                $orderSaleInvoice->update($saleInvoiceData);
                $orderSale = isset($orderSaleInvoice->getOrderSale)?$orderSaleInvoice->getOrderSale:null;
                // $itemCount = $request->impression;
                foreach ($orderSale as $key => $item) {
                    $i=$key+1;
                    $saleData = $request->only('client_id', 'date', 'note', 'status');
                    $saleData['created_by_id']=$saleInvoiceData['created_by_id'];
                    $saleData['order_sale_invoice_id']=$orderSaleInvoice->id;
                    $saleData['product_id']=$request->input('product_id'.$i);
                    $saleData['badge_id']=$request->input('badge_id'.$i);
                    $saleData['type']=$request->input('type'.$i);
                    $saleData['unit_id']=$request->input('unit_id'.$i);
                    $saleData['rate']=$request->input('rate'.$i);
                    $saleData['parUnitQty']=$request->input('parUnitQty'.$i);
                    $saleData['qty']=$request->input('qty'.$i);
                    $saleData['discount']=$request->input('itemDiscount'.$i);
                    $saleData['discountType']=$request->input('itemDiscountType'.$i);
                    $saleData['total']=$request->input('total'.$i);
                    if (isset($saleData['product_id']) && isset($saleData['total'])) {
                        $product=Product::findOrFail($saleData['product_id']);
                        $saleData['lessable_qty']=$saleData['qty'];
                        $saleData['category_id'] = $product->category_id;
                        $item->update($saleData);

                    }
                }
                // return view('admin.saleRegisters.order_sale.edit', compact('orderSale', 'orderSaleInvoice'));
                return redirect()->back()->with('message', 'Successfully Sales Updated!');
            }
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Sale  $sale
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            $orderSaleInvoice = OrderSaleInvoice::findOrFail($id);
            $orderSales=isset($orderSaleInvoice->getOrderSale)?$orderSaleInvoice->getOrderSale:null;
            $orderSales->each->delete();
            OrderSaleInvoice::destroy($id);
            return redirect('admin/saleRegisters/order_sale');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            OrderSaleInvoice::whereNotNull('id')->delete();
            return redirect('admin/saleRegisters/order_sale');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function setItem(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            $inputData= array();
            $inputData['product_id']=$_GET['product_id'];
            $inputData['unit_id']=$_GET['unit_id'];
            $inputData['type']=$_GET['type'];
            $data = Product::findOrFail($inputData['product_id']);
            $dataVariation = isset($data->getVariation)?$data->getVariation:null;
            $price='';
            $unitOption=isset($data->getUnit)?$data->getUnit:null;
            $single=true;
            $variation=null;
            if (count($dataVariation)>0) {
                $unitOption=$dataVariation;
                $single=false;
            }
            if ($inputData['unit_id'] && $dataVariation) {
                $variation=$dataVariation->where('product_id', $inputData['product_id'])
                    ->where('unit_id', $inputData['unit_id'])->first();
                if (isset($variation->retail_price) && $inputData['type']=='Retail') {
                    $price=$variation->retail_price;
                }elseif (isset($variation->wholesale_price) && $inputData['type']=='Wholesale') {
                    $price=$variation->wholesale_price;
                }else {
                    $price=null;
                }
            }
            return ['setItem'=>$data, 'variation'=>$variation,'variationPrice'=>$price, 'unitOption'=>$unitOption, 'single'=>$single];
        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    public function setClientData(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            $inputData= array();
            $inputData['client_id']=$_GET['client_id'];
            $data = Client::findOrFail($inputData['client_id']);
            return ['setClientData'=>$data];
        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    public function setItemBarcode(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->buyer_request)){
            $inputData= array();
            $inputData['code']=$_GET['code'];
            $data = Product::where('code', $inputData['code'])->first();
            $dataVariation = isset($data->getVariation)?$data->getVariation:null;
            $unitOption=isset($data->getUnit)?$data->getUnit:null;
            $single=true;
            if (count($dataVariation)>0) {
                $unitOption=$dataVariation;
                $single=false;
            }
            return ['setItem'=>$data, 'unitOption'=>$unitOption, 'single'=>$single];

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

}
