<?php

namespace App\Http\Controllers\Admin\SaleRegisters;

use App\Sale;
use App\SaleInvoice;
use App\Product;
use App\Payment;
use App\PaymentTypes;
use App\Variation;
use App\SMS;
use App\Client;
use App\ClientBalance;
use App\Accounting;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class SaleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleInvoice = SaleInvoice::orderBy('id', 'desc')->paginate(200);
            return view('admin.saleRegisters.sale.index', compact('saleInvoice'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $products = Product::orderBy('title', 'asc')->get();
            return view('admin.saleRegisters.sale.create', compact('products'));
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    public function pos()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $products = Product::orderBy('title', 'asc')->get();
            return view('admin.saleRegisters.sale.pos', compact('products'));
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $this->validate($request, [
                'client_id' => 'required',
                'date' => 'required',
                'subTotal' => 'required',
                'payable' => 'required',
                'paid' => 'required',
            ]);
            // $requestData = $request->all();

            $saleInvoiceData = $request->only('created_by_id', 'client_id', 'reference_id', 'date', 'phone', 'subTotal', 'vat', 'vatType', 'discount', 'discountType', 'discountNote', 'coupon', 'shipment', 'advance', 'payable', 'paid', 'due', 'note', 'status', 'labour_cost');
            $saleInvoiceData['created_by_id']=Auth::user()->id;
            $saleInvoiceData['due']=$saleInvoiceData['payable']-$saleInvoiceData['paid'];
            $saleInvoiceClientData=Client::findOrFail($saleInvoiceData['client_id']);
            $saleInvoiceData['old_balance']=($saleInvoiceClientData->balance)-($saleInvoiceClientData->due);
            $saleInvoice=SaleInvoice::create($saleInvoiceData);

            $itemCount = $request->impression;
            for ($i=1; $i <= $itemCount; $i++) {
                $saleData = $request->only('client_id', 'date', 'note', 'status');
                $saleData['created_by_id']=$saleInvoiceData['created_by_id'];
                $saleData['sale_invoice_id']=$saleInvoice->id;
                $saleData['product_id']=$request->input('product_id'.$i);
                $saleData['badge_id']=$request->input('badge_id'.$i);
                $saleData['type']=$request->input('type'.$i);
                $saleData['unit_id']=$request->input('unit_id'.$i);
                $saleData['rate']=$request->input('rate'.$i);
                $saleData['parUnitQty']=$request->input('parUnitQty'.$i);
                $saleData['qty']=$request->input('qty'.$i);
                $saleData['discount']=$request->input('itemDiscount'.$i);
                $saleData['discountType']=$request->input('itemDiscountType'.$i);
                $saleData['total']=$request->input('total'.$i);
                if (isset($saleData['product_id']) && isset($saleData['total']) && isset($saleData['qty']) && $saleData['qty']!=0) {
                    $product=Product::findOrFail($saleData['product_id']);
                    $productPurchase=($product->purchase_value)/(isset($product->stock_qty)?$product->stock_qty:'1');
                    // $productQty=$product->qty;
                    $purchase_value=$productPurchase*$saleData['qty'];
                    $saleData['purchase_value']=$purchase_value;
                    $saleData['category_id'] = $product->category_id;
                    $sale=Sale::create($saleData);
                    $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')-$saleData['qty'];
                    $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')-$purchase_value;
                    $product->update($productData);

                }
            }

            // payment
            $paymentCount = $request->paymentImpression;
            for ($i=1; $i <= $paymentCount; $i++){
                $paymentData['date']=$saleInvoice->date;
                $paymentData['created_by_id']=$saleInvoice->created_by_id;
                $paymentData['client_id']=$saleInvoice->client_id;
                $paymentData['invoice_id']=$saleInvoice->id;
                $paymentData['payment_type_id']=$request->input('payment_type_id'.$i);
                $paymentData['payment_category']='Customer-Payment';
                $paymentData['type']='IN';
                $paymentData['payment_amount']=$request->input('payment_amount'.$i);
                $paymentData['payment_note']='Sales INV-'.$saleInvoice->id.' '.$request->input('payment_note'.$i);
                if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount']) && $paymentData['payment_amount']>0) {
                    $payment=Payment::create($paymentData);
                    $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                    $incoming_balance = (isset($balance->incoming_balance)?$balance->incoming_balance:'0')+($paymentData['payment_amount']);
                    $paymentTypesData['incoming_balance'] = $incoming_balance;
                    $balance->update($paymentTypesData);
                }
            }

            //client balance calculate
            $client=Client::findOrFail($saleInvoice->client_id);
            $advance_paid=$saleInvoice->advance;
            $balance=(isset($client->balance)?$client->balance:'0')-($advance_paid);
            $due=(isset($client->due)?$client->due:'0')+$saleInvoiceData['due'];
            if ($balance>$due) {
                $clientDate['balance']=$balance-$due;
                $clientDate['due']=0;
            }else {
                $clientDate['balance']=0;
                $clientDate['due']=$due-$balance;
            }
            $client->update($clientDate);

            //accounting record
            $accountingData['created_by_id']=$saleInvoice->created_by_id;
            $accountingData['client_id']=$saleInvoice->client_id;
            $accountingData['ref_id']=$saleInvoice->id;
            $accountingData['date']=$saleInvoice->date;
            $accountingData['debit']=$saleInvoice->paid; // paid
            // $accountingData['credit']=($saleInvoice->payable); //payable
            $accountingData['credit']=($saleInvoice->subTotal)+($saleInvoice->shipment)+($saleInvoice->labour_cost); //sales amount
            $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
            $accountingData['description']='Sales';
            $accountingData['note']=$saleInvoice->note;
            $accounting=Accounting::create($accountingData);

            //SMS sending section start
            if ($request->sms==1) {
                $smsData['created_by_id']=$saleInvoice->created_by_id;
                $smsData['Title']='Sale Item';
                if (isset($saleInvoice->phone)) {
                    $smsData['number']=isset($saleInvoice->phone)?$saleInvoice->phone:'';
                }else{
                    $smsData['number']=isset($saleInvoice->getClient->phone)?$saleInvoice->getClient->phone:'';
                }
                $totalBalance=isset($saleInvoice->getClient->balance)?$saleInvoice->getClient->balance:'0';
                $totalDue=isset($saleInvoice->getClient->due)?$saleInvoice->getClient->due:'0';
                $invoiceWiseTotal = ($saleInvoice->payable)+($saleInvoice->advance);
                $advanceAndPaid = ($saleInvoice->paid)+($saleInvoice->advance);
                $smsData['message']='Dealer: M/S CloudBari Traders, Sale Completed! Customer Name '.$client->title.' Invoice number/ref: '.$saleInvoice->id.', Invoice wise total: '.$invoiceWiseTotal.' BDT, Old Due: '.$client->due.' BDT, Advance/Paid: '.$advanceAndPaid.' BDT, Total current balance : '.$totalBalance.' BDT, Total due balance: '.$totalDue.' BDT, Date: '.$saleInvoiceData['date'];
                $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                if ($smsResult['status']=="SENT") {
                    SMS::create($smsData);
                    // return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                }else{
                    return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                }
            }
            //SMS sending section end

            if ($request->printOn==1) {
                $sale=isset($saleInvoice)?$saleInvoice->getSale:null;
                return view('admin.saleRegisters.sale.show', compact('saleInvoice','sale'));
            }else{
                return redirect()->back()->with('message', 'Successfully Sale completed!');
            }
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Sale  $sale
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleInvoice = SaleInvoice::findOrFail($id);
            $sale=isset($saleInvoice)?$saleInvoice->getSale:null;
            return view('admin.saleRegisters.sale.show', compact('saleInvoice','sale'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Sale  $sale
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleInvoice = SaleInvoice::findOrFail($id);
            $sale = isset($saleInvoice->getSale)?$saleInvoice->getSale:null;
            return view('admin.saleRegisters.sale.edit', compact('sale', 'saleInvoice'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Sale  $sale
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $this->validate($request, [
                'client_id' => 'required',
                'date' => 'required',
                'subTotal' => 'required',
                'payable' => 'required',
                'paid' => 'required',
            ]);
            // $requestData = $request->all();
            $saleInvoice = SaleInvoice::findOrFail($id);
            $saleInvoiceData = $request->only('created_by_id', 'client_id', 'reference_id', 'date', 'phone', 'subTotal', 'vat', 'vatType', 'discount', 'discountType', 'discountNote', 'coupon', 'shipment', 'payable', 'paid', 'due', 'note', 'status', 'labour_cost');
            $saleInvoiceData['created_by_id']=Auth::user()->id;
            $saleInvoiceData['due']=$saleInvoiceData['payable']-$saleInvoiceData['paid'];
            $lessAmount=($saleInvoice->subTotal)-($saleInvoiceData['subTotal']);
            $saleInvoice->update($saleInvoiceData);
            $sale = isset($saleInvoice->getSale)?$saleInvoice->getSale:null;

            // $itemCount = $request->impression;
            foreach ($sale as $key => $item) {
                $i=$key+1;
                $saleData = $request->only('client_id', 'date', 'note', 'status');
                $saleData['created_by_id']=$saleInvoiceData['created_by_id'];
                $saleData['sale_invoice_id']=$saleInvoice->id;
                $saleData['product_id']=$request->input('product_id'.$i);
                $saleData['badge_id']=$request->input('badge_id'.$i);
                $saleData['type']=$request->input('type'.$i);
                $saleData['unit_id']=$request->input('unit_id'.$i);
                $saleData['rate']=$request->input('rate'.$i);
                $saleData['parUnitQty']=$request->input('parUnitQty'.$i);
                $saleData['qty']=$request->input('qty'.$i);
                $saleData['discount']=$request->input('itemDiscount'.$i);
                $saleData['discountType']=$request->input('itemDiscountType'.$i);
                $saleData['total']=$request->input('total'.$i);
                if (isset($saleData['product_id']) && isset($saleData['total'])) {
                    $item->update($saleData);

                }
            }

            //client balance calculate
            $client=Client::findOrFail($saleInvoice->client_id);
            $balance=(isset($client->balance)?$client->balance:'0')+($lessAmount);
            $due=(isset($client->due)?$client->due:'0');
            if ($balance>$due) {
                $clientDate['balance']=$balance-$due;
                $clientDate['due']=0;
            }else {
                $clientDate['balance']=0;
                $clientDate['due']=$due-$balance;
            }
            $client->update($clientDate);
            //accounting record
            $accounting=Accounting::where('ref_id', $saleInvoice->id)
                                ->where('client_id', $saleInvoice->client_id)
                                ->where('description', 'Sales')
                                ->first();
            $accountingData['created_by_id']=$saleInvoice->created_by_id;
            $accountingData['client_id']=$saleInvoice->client_id;
            $accountingData['ref_id']=$saleInvoice->id;
            $accountingData['date']=$saleInvoice->date;
            $accountingData['debit']=$saleInvoice->paid; // paid
            // $accountingData['credit']=($saleInvoice->payable); //payable
            $accountingData['credit']=($saleInvoice->subTotal)+($saleInvoice->shipment)+($saleInvoice->labour_cost); //sales amount
            $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
            $accountingData['description']='Sales';
            $accountingData['note']=$saleInvoice->note;
            $accounting->update($accountingData);

            // return view('admin.saleRegisters.order_sale.edit', compact('orderSale', 'saleInvoice'));
            return redirect()->back()->with('message', 'Successfully Sales Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Sale  $sale
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleInvoice = SaleInvoice::findOrFail($id);
            $sales=isset($saleInvoice->getSale)?$saleInvoice->getSale:null;
            foreach ($sales as $item) {
                $product=Product::findOrFail($item->product_id);
                $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')+($item->qty);
                $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')+($item->purchase_value);
                $product->update($productData);
            }

            $payment = Payment::where('invoice_id', $id)->where('payment_category', 'Customer-Payment')->get();
            foreach ($payment as $item) {
                $balance=PaymentTypes::findOrFail($item->payment_type_id);
                $incoming_balance = (isset($balance->incoming_balance)?$balance->incoming_balance:'0')-($item->payment_amount);
                $paymentTypesData['incoming_balance'] = $incoming_balance;
                $balance->update($paymentTypesData);
            }
            //client balance calculate
            $client=Client::findOrFail($saleInvoice->client_id);
            $advance_paid=$saleInvoice->advance;
            $due_amount=$saleInvoice->due;
            $balance=(isset($client->balance)?$client->balance:'0')+($advance_paid);
            $due=(isset($client->due)?$client->due:'0')-($due_amount);
            if ($balance>$due) {
                $clientDate['balance']=$balance-$due;
                $clientDate['due']=0;
            }else {
                $clientDate['balance']=0;
                $clientDate['due']=$due-$balance;
            }
            $client->update($clientDate);

            $accounting = Accounting::where('ref_id', $id)->where('description', 'Sales')->delete();
            $sales->each->delete();
            $payment->each->delete();
            SaleInvoice::destroy($id);
            return redirect('admin/saleRegisters/sale');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            SaleInvoice::whereNotNull('id')->delete();
            Sale::whereNotNull('id')->delete();
            return redirect('admin/saleRegisters/sale');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function advanceSearchIndex(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $requestData = $request;
            $dbQuery = SaleInvoice::query();
            if ($request->client_id!='') {
                $dbQuery->where('client_id', $request->client_id);
            }
            if ($request->invoice_id!='') {
                $dbQuery->where('id', $request->invoice_id);
            }
            $saleInvoice = $dbQuery->get();
            return view('admin.saleRegisters.sale.index', compact('saleInvoice'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }

    public function setItem(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $inputData= array();
            $inputData['product_id']=$_GET['product_id'];
            $inputData['unit_id']=$_GET['unit_id'];
            $inputData['type']=$_GET['type'];
            $data = Product::findOrFail($inputData['product_id']);
            $dataVariation = isset($data->getVariation)?$data->getVariation:null;
            $price='';
            $variationparUnitQty='';
            $unitOption=isset($data->getUnit)?$data->getUnit:null;
            $single=true;
            $variation=null;
            if (count($dataVariation)>0) {
                $unitOption=$dataVariation;
                $single=false;
            }
            if ($inputData['unit_id'] && $dataVariation) {
                $variation=$dataVariation->where('product_id', $inputData['product_id'])
                    ->where('unit_id', $inputData['unit_id'])->first();
                if (isset($variation->qty) && $variation->qty!=0 && $inputData['type']=='Retail') { 
                    $retail_price=isset($data->retail_price)?$data->retail_price:'0';
                    $qty=$data->qty;
                    $variationQty=isset($variation->qty)?$variation->qty:'0';
                    $price=($retail_price/$qty)*$variationQty;
                }elseif (isset($variation->qty) && $variation->qty!=0 && $inputData['type']=='Wholesale') { 
                    $wholesale_price=isset($data->wholesale_price)?$data->wholesale_price:'0';
                    $qty=$data->qty;
                    $variationQty=isset($variation->qty)?$variation->qty:'0';
                    $price=($wholesale_price/$qty)*$variationQty;
                }else {
                    $price=null;
                }
                if (isset($variation->qty)) {
                    $variationparUnitQty=$variation->qty;
                }else {
                    $variationparUnitQty=null;
                }
            }
            return ['setItem'=>$data, 'variation'=>$variation,'variationPrice'=>$price, 'variationparUnitQty'=>$variationparUnitQty, 'unitOption'=>$unitOption, 'single'=>$single];
        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function setItemBarcode(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $inputData= array();
            $inputData['code']=$_GET['code'];
            $data = Product::where('code', $inputData['code'])->first();
            $dataVariation = isset($data->getVariation)?$data->getVariation:null;
            $unitOption=isset($data->getUnit)?$data->getUnit:null;
            $single=true;
            if (count($dataVariation)>0) {
                $unitOption=$dataVariation;
                $single=false;
            }
            return ['setItem'=>$data, 'unitOption'=>$unitOption, 'single'=>$single];

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    public function setItemProductId(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $inputData= array();
            $inputData['product_id']=$_GET['product_id'];
            $data = Product::where('id', $inputData['product_id'])->first();
            $dataVariation = isset($data->getVariation)?$data->getVariation:null;
            $unitOption=isset($data->getUnit)?$data->getUnit:null;
            $single=true;
            if (count($dataVariation)>0) {
                $unitOption=$dataVariation;
                $single=false;
            }
            return ['setItem'=>$data, 'unitOption'=>$unitOption, 'single'=>$single];

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    // public function setItemProductId(){
    //     if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
    //         $inputData= array();
    //         $inputData['product_id']=$_GET['product_id'];
    //         $data = Product::where('id', $inputData['product_id'])->first();
    //         $dataVariation = isset($data->getVariation)?$data->getVariation:null;
    //         $unitOption=isset($data->getUnit)?$data->getUnit:null;
    //         $single=true;
    //         if (count($dataVariation)>0) {
    //             $unitOption=$dataVariation;
    //             $single=false;
    //         }
    //         return ['setItem'=>$data, 'unitOption'=>$unitOption, 'single'=>$single];

    //     }else{
    //         $permission="'Sell Level' permission needed!!!";
    //         return view('admin.notify.permission_denied', compact('permission'));
    //     }
    // }
    public function setClientData(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $inputData= array();
            $inputData['client_id']=$_GET['client_id'];
            $data = Client::findOrFail($inputData['client_id']);
            return ['setClientData'=>$data];
        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
    // due Invoice
    public function dueClient()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $dueClient = Client::where('type', 'customer')->whereNotNull('due')->where('due', '>', '0')->orderBy('id', 'desc')->paginate(50);
            return view('admin.saleRegisters.sale.dueClient', compact('dueClient'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }
    public function dueClientPaid()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $clientBalanceData['created_by_id']=Auth::user()->id;
            $clientBalanceData['client_id']=$_GET['client_id'];
            $clientBalanceData['payment_type_id']=$_GET['payment_type_id'];
            $clientBalanceData['date']=$_GET['date'];
            $clientBalanceData['amount']=$_GET['amount'];
            $clientBalanceData['note']=$_GET['note'];
            $clientBalanceData['type']='IN';
            $balanceClient=Client::findOrFail($clientBalanceData['client_id']);
            $clientBalanceData['old_balance'] = $balanceClient->balance;
            $clientBalanceData['old_due'] = $balanceClient->due;
            $clientBalance = ClientBalance::create($clientBalanceData);

            // payment
            $paymentData['date']=$clientBalanceData['date'];
            $paymentData['created_by_id']=$clientBalanceData['created_by_id'];
            $paymentData['client_id']=$clientBalanceData['client_id'];
            $paymentData['payment_type_id']=$clientBalanceData['payment_type_id'];
            $paymentData['payment_amount']=$clientBalanceData['amount'];
            $paymentData['payment_note']='ClientBalance CB-'.$clientBalanceData['note'];
            if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount']) && $paymentData['payment_amount']>0) {
                $balance=(isset($balanceClient->balance)?$balanceClient->balance:'0')+($paymentData['payment_amount']);
                $due=isset($balanceClient->due)?$balanceClient->due:'0';
                if ($balance>$due) {
                    $balanceClientData['balance']=$balance-$due;
                    $balanceClientData['due']=0;
                }else {
                    $balanceClientData['balance']=0;
                    $balanceClientData['due']=$due-$balance;
                }
                $balanceClient->update($balanceClientData);

                $paymentData['payment_category']='Customer-Payment';
                $paymentData['type']='IN';
                $payment=Payment::create($paymentData);

                $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                $incoming_balance = (isset($balance->incoming_balance)?$balance->incoming_balance:'0')+($paymentData['payment_amount']);
                $paymentTypesDate['incoming_balance'] = $incoming_balance;
                $balance->update($paymentTypesDate);

                //accounting record
                $accountingData['created_by_id']=$payment->created_by_id;
                $accountingData['client_id']=$payment->client_id;
                $accountingData['ref_id']=$payment->id;
                $accountingData['date']=$payment->date;
                $accountingData['debit']=$payment->payment_amount; //payable
                $accountingData['credit']=0; // paid
                $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
                $accountingData['description']='Customer-Payment';
                $accountingData['note']=$payment->payment_note;
                $accounting=Accounting::create($accountingData);

                //SMS sending section start
                $sms = $_GET['sms'];
                $smsStatus=null;
                if ($sms=='true') {
                    $smsData['created_by_id']=$clientBalance->created_by_id;
                    $smsData['number']=isset($clientBalance->getClient->phone)?$clientBalance->getClient->phone:'';
                    $smsTemplateClient=isset($clientBalance->getClient->title)?$clientBalance->getClient->title:null;
                    $smsData['message']='Dealer: M/S CloudBari Traders, get due payment from '.$smsTemplateClient.'. Paid Amount: '.$clientBalance->amount.' BDT, Total due balance : '.$balanceClientData['due'].' BDT, Total current balance : '.$balanceClientData['balance'].' BDT, Date: '.$clientBalanceData['date'];
                    $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                    if ($smsResult['status']=="SENT") {
                        SMS::create($smsData);
                    }
                    $smsStatus=$smsResult['status'].' '.$smsResult['statusmsg'];
                }
                //SMS sending section end

            }

            return ['data'=>'Paid', 'balance'=>$balanceClientData['balance'], 'due'=>$balanceClientData['due'], 'smsStatus'=>$smsStatus];
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }
    // due Invoice end

    // public function payment()
    // {
    //     if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
    //         return view('admin.saleRegisters.sale.form.payment');
    //     }else{
    //         $permission="'Create Level' permission needed!!!";
    //         return view('admin.notify.permission_denied', compact('permission'));
    //     }
    // }

    public function return($sale_invoice_id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleInvoice = SaleInvoice::findOrFail($sale_invoice_id);
            $sale = isset($saleInvoice->getSale)?$saleInvoice->getSale:null;
            return view('admin.saleRegisters.return.create', compact('saleInvoice', 'sale'));
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function deliveryCopy($sale_invoice_id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleInvoice = SaleInvoice::findOrFail($sale_invoice_id);
            $sale=isset($saleInvoice)?$saleInvoice->getSale:null;
            return view('admin.saleRegisters.sale.deliveryCopy', compact('saleInvoice','sale'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
