<?php

namespace App\Http\Controllers\Admin\SaleRegisters;

use App\SaleReturn;
use App\SaleReturnInvoice;
use App\SaleInvoice;
use App\Sale;
use App\Variation;
use App\Product;
use App\Payment;
use App\PaymentTypes;
use App\Client;
use App\Accounting;
use App\SMS;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class SaleReturnController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleReturnInvoice = SaleReturnInvoice::orderBy('id', 'desc')->paginate(50);
            return view('admin.saleRegisters.return.index', compact('saleReturnInvoice'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            return view('admin.saleRegisters.return.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $this->validate($request, [
                'sale_invoice_id' => 'required',
                'date' => 'required',
                'payable' => 'required',
            ]);
            // $requestData = $request->all();

            $saleReturnInvoiceData = $request->only('created_by_id', 'sale_invoice_id', 'date', 'subTotal', 'shipment', 'payable', 'paid', 'due', 'note', 'status', 'labour_cost');
            $saleReturnInvoiceData['created_by_id']=Auth::user()->id;
            $addBalance=$saleReturnInvoiceData['payable']-$saleReturnInvoiceData['paid'];
            $saleInvoice=SaleInvoice::findOrFail($request->sale_invoice_id);
            $saleReturnInvoiceClientData=Client::findOrFail(isset($saleInvoice->client_id)?$saleInvoice->client_id:'0');
            $saleReturnInvoiceData['old_balance']=($saleReturnInvoiceClientData->balance)-($saleReturnInvoiceClientData->due);
            $saleReturnInvoiceData['client_id']=isset($saleInvoice->client_id)?$saleInvoice->client_id:null;
            //sales invoice update
            $saleInvoiceData['return_amount']=(isset($saleInvoice->return_amount)?$saleInvoice->return_amount:'0')+($request->subTotal);
            if ($saleInvoiceData['return_amount']>0 && $saleInvoiceData['return_amount']<=$saleInvoice->subTotal) {
                $saleReturnInvoice=SaleReturnInvoice::create($saleReturnInvoiceData);
                $saleInvoice->update($saleInvoiceData);

                $itemCount = $request->impression;
                for ($i=0; $i < $itemCount; $i++) {
                    $saleReturnData = $request->only('date', 'note', 'status');
                    $saleReturnData['created_by_id']=$saleReturnInvoice->created_by_id;
                    $saleReturnData['sale_return_invoice_id']=$saleReturnInvoice->id;
                    $saleReturnData['sale_item_id']=$request->input('sale_item_id'.$i);
                    $saleReturnData['client_id']=$saleReturnInvoice->client_id;
                    $saleReturnData['product_id']=$request->input('product_id'.$i);
                    $saleReturnData['badge_id']=$request->input('badge_id'.$i);
                    $saleReturnData['type']=$request->input('type'.$i);
                    $saleReturnData['unit_id']=$request->input('unit_id'.$i);
                    $saleReturnData['rate']=$request->input('rate'.$i);
                    $saleReturnData['parUnitQty']=$request->input('parUnitQty'.$i);
                    $saleReturnData['qty']=$request->input('qty'.$i);
                    $saleReturnData['discount']=$request->input('itemDiscount'.$i);
                    $saleReturnData['discountType']=$request->input('itemDiscountType'.$i);
                    $saleReturnData['total']=$request->input('total'.$i);

                    $saleItem=Sale::findOrFail($saleReturnData['sale_item_id']);
                    $sale_pre_total=isset($saleItem->total)?$saleItem->total:'0';

                    if (isset($saleReturnData['product_id']) && isset($saleReturnData['total']) && $request->input('qty'.$i) && ($request->input('qty'.$i))>0 && $sale_pre_total>=$saleReturnData['total']) {
                        $product=Product::findOrFail($saleReturnData['product_id']);
                        $productPurchase=($product->purchase_value)/(isset($product->stock_qty)?$product->stock_qty:'1');
                        // $productQty=$product->qty;
                        $purchase_value=$productPurchase*$saleReturnData['qty'];
                        $saleReturnData['category_id'] = $product->category_id;
                        $saleReturn=SaleReturn::create($saleReturnData);
                        $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')+$saleReturnData['qty'];
                        $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')+$purchase_value;
                        $product->update($productData);

                        // sale item update
                        $saleData['return_amount'] = (isset($saleItem->return_amount)?$saleItem->return_amount:'0')+$saleReturnData['total'];
                        $saleItem->update($saleData);
                    }
                }

                // payment
                $paymentCount = $request->paymentImpression;
                for ($i=1; $i <= $paymentCount; $i++){
                    $paymentData['date']=$saleReturnInvoice->date;
                    $paymentData['created_by_id']=$saleReturnInvoice->created_by_id;
                    $paymentData['client_id']=$saleReturnInvoice->client_id;
                    $paymentData['invoice_id']=$saleReturnInvoice->id;
                    $paymentData['payment_type_id']=$request->input('payment_type_id'.$i);
                    $paymentData['payment_category']='Customer-Payment-Return';
                    $paymentData['type']='OUT';
                    $paymentData['payment_amount']=$request->input('payment_amount'.$i);
                    $paymentData['payment_note']='PR-000'.$saleReturnInvoice->id.' '.$request->input('payment_note'.$i);
                    if (isset($paymentData['payment_type_id']) && isset($paymentData['payment_amount']) && $paymentData['payment_amount']>0) {
                        $payment=Payment::create($paymentData);
                        $balance=PaymentTypes::findOrFail($paymentData['payment_type_id']);
                        $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')+($paymentData['payment_amount']);
                        $paymentTypesData['outgoing_balance'] = $outgoing_balance;
                        $balance->update($paymentTypesData);
                    }
                }


                //client balance calculate
                $client=Client::findOrFail($saleInvoice->client_id);
                $balance=(isset($client->balance)?$client->balance:'0')+($addBalance);
                $due=(isset($client->due)?$client->due:'0')-$request->due;
                if ($balance>$due) {
                    $clientDate['balance']=$balance-$due;
                    $clientDate['due']=0;
                }else {
                    $clientDate['balance']=0;
                    $clientDate['due']=$due-$balance;
                }
                $client->update($clientDate);

                //accounting record
                $accountingData['created_by_id']=$saleReturnInvoice->created_by_id;
                $accountingData['client_id']=$saleReturnInvoice->client_id;
                $accountingData['ref_id']=$saleReturnInvoice->id;
                $accountingData['date']=$saleReturnInvoice->date;
                $accountingData['debit']=($saleReturnInvoice->subTotal)+($saleReturnInvoice->shipment)+($saleReturnInvoice->labour_cost); //payable
                $accountingData['credit']=$saleReturnInvoice->paid; // paid
                $accountingData['balance']=$accountingData['debit']-$accountingData['credit'];
                $accountingData['description']='Sales-Return';
                $accountingData['note']=$saleReturnInvoice->note;
                $accounting=Accounting::create($accountingData);

                //SMS sending section start
                if ($request->sms==1) {
                    $smsData['created_by_id']=$saleReturnInvoice->created_by_id;
                    $smsData['Title']='Return Sales';
                    if (isset($saleReturnInvoice->getSaleInvoice->phone)) {
                        $smsData['number']=isset($saleReturnInvoice->getSaleInvoice->phone)?$saleReturnInvoice->getSaleInvoice->phone:'';
                    }else{
                        $smsData['number']=isset($saleReturnInvoice->getSaleInvoice->getClient->phone)?$saleReturnInvoice->getSaleInvoice->getClient->phone:'';
                    }
                    $totalBalance=isset($saleReturnInvoice->getSaleInvoice->getClient->balance)?$saleReturnInvoice->getSaleInvoice->getClient->balance:'0';
                    $totalDue=isset($saleReturnInvoice->getSaleInvoice->getClient->due)?$saleReturnInvoice->getSaleInvoice->getClient->due:'0';

                    $smsData['message']='Dealer: M/S CloudBari Traders, Sale Return Completed! Return Invoice Number/Ref: '.$saleReturnInvoice->id.', Invoice wise return total: '.$saleReturnInvoice->return_amount.' BDT, Old Due: '.$client->due.' BDT, Paid: '.$saleReturnInvoice->paid.' BDT, Total current balance: '.$totalBalance.' BDT, Total due balance: '.$totalDue.' BDT, Date: '.$saleReturnInvoiceData['date'];
                    $smsResult=SMS::getSMS($smsData['number'], $smsData['message']);
                    if ($smsResult['status']=="SENT") {
                        SMS::create($smsData);
                        // return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                    }else{
                        return redirect()->back()->with('message', $smsResult['status'].'! '.$smsResult['statusmsg']);
                    }
                }
                //SMS sending section end

                if ($request->printOn==1) {
                    $saleReturn=isset($saleReturnInvoice->getSaleReturn)?$saleReturnInvoice->getSaleReturn:null;
                    return view('admin.saleRegisters.return.show', compact('saleReturnInvoice','saleReturn'));
                }else{
                    return redirect()->back()->with('message', 'Successfully Sales Return completed!');
                }
            }else {
                return redirect()->back()->with('message', 'faild');
            }

        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\saleReturn  $sale
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleReturnInvoice = SaleReturnInvoice::findOrFail($id);
            $saleReturn=isset($saleReturnInvoice->getSaleReturn)?$saleReturnInvoice->getSaleReturn:null;
            return view('admin.saleRegisters.return.show', compact('saleReturnInvoice','saleReturn'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\saleReturn  $sale
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleReturn = SaleReturn::findOrFail($id);
            return view('admin.saleRegisters.return.edit', compact('saleReturn'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\saleReturn  $sale
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
        //     $this->validate($request, [
        //         'title' => 'required|max:50',
        //     ]);
        //     $requestData = $request->all();
        //     $saleReturn = SaleReturn::findOrFail($id);

        //     $saleReturn->update($requestData);

        //     return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        // }else{
        //     $permission="'Update Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\saleReturn  $sale
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $saleReturnInvoice = SaleReturnInvoice::findOrFail($id);
            $saleReturn=isset($saleReturnInvoice->getSaleReturn)?$saleReturnInvoice->getSaleReturn:null;

            // sale item update
            foreach ($saleReturn as $item) {
                $saleItem=Sale::findOrFail($item->sale_item_id);
                $saleData['return_amount'] = (isset($saleItem->return_amount)?$saleItem->return_amount:'0')-($item->total);
                $saleItem->update($saleData);

                //product update
                $product=Product::findOrFail($item->product_id);
                $purchase_value=(($saleItem->purchase_value)/($saleItem->qty))*($item->qty);
                $productData['stock_qty']=(isset($product->stock_qty)?$product->stock_qty:'0')-($item->qty);
                $productData['purchase_value']=(isset($product->purchase_value)?$product->purchase_value:'0')-($purchase_value);
                $product->update($productData);
            }

            //sales invoice update
            $saleInvoice=SaleInvoice::findOrFail($saleReturnInvoice->sale_invoice_id);
            $saleInvoiceData['return_amount']=(isset($saleInvoice->return_amount)?$saleInvoice->return_amount:'0')-($saleReturnInvoice->subTotal);
            $saleInvoice->update($saleInvoiceData);

            $payment = Payment::where('invoice_id', $id)->where('payment_category', 'Customer-Payment-Return')->get();
            foreach ($payment as $item) {
                $balance=PaymentTypes::findOrFail($item->payment_type_id);
                $outgoing_balance = (isset($balance->outgoing_balance)?$balance->outgoing_balance:'0')-($item->payment_amount);
                $paymentTypesData['outgoing_balance'] = $outgoing_balance;
                $balance->update($paymentTypesData);
            }

            //client balance calculate
            $client=Client::findOrFail($saleReturnInvoice->client_id);
            $addBalance=($saleReturnInvoice->payable)-($saleReturnInvoice->paid);
            $balance=(isset($client->balance)?$client->balance:'0')-($addBalance);
            $due=(isset($client->due)?$client->due:'0')+($saleReturnInvoice->due);
            if ($balance>$due) {
                $clientDate['balance']=$balance-$due;
                $clientDate['due']=0;
            }else {
                $clientDate['balance']=0;
                $clientDate['due']=$due-$balance;
            }
            $client->update($clientDate);

            $accounting = Accounting::where('ref_id', $id)->where('description', 'Sales-Return')->delete();
            $saleReturn->each->delete();
            $payment->each->delete();
            SaleReturnInvoice::destroy($id);
            return redirect('admin/saleRegisters/return');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            SaleReturnInvoice::whereNotNull('id')->delete();
            return redirect('admin/saleRegisters/return');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function setItem(){
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $inputData= array();
            $inputData['sale_invoice_id']=$_GET['sale_invoice_id'];
            $data = SaleInvoice::findOrFail($inputData['sale_invoice_id']);
            $data2 = isset($data->getSale)?$data->getSale:null;
            $data3 = isset($data->getClient)?$data->getClient:null;
            return ['setItem'=>$data, 'setItemSale'=>$data2, 'setClient'=>$data3];

        }else{
            $permission="'Sell Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
