<?php

namespace App\Http\Controllers\Admin\TemplateMaker;

use App\ReceiptItem;
use App\Receipt;
use App\Client;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class ReceiptController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $receipt = Receipt::orderBy('id', 'desc')->paginate(200);
            return view('admin.templateMaker.receipt.index', compact('receipt'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            return view('admin.templateMaker.receipt.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $this->validate($request, [
                'receipt_to' => 'required',
                'date' => 'required',
                'total' => 'required',
            ]);
            // $requestData = $request->all();
            $receiptData = $request->only('receipt_to', 'date', 'total', 'paid', 'due', 'note', 'total_in_word');
            $receipt=Receipt::create($receiptData);
            
            $itemCount = $request->impression;
            for ($i=1; $i <= $itemCount; $i++) { 
                $receiptItemData = $request->only('date');
                $receiptItemData['receipt_id']=$receipt->id;
                $receiptItemData['qty']=$request->input('qty'.$i);
                $receiptItemData['rate']=$request->input('rate'.$i);
                $receiptItemData['amount']=$request->input('amount'.$i);
                $receiptItemData['description']=$request->input('description'.$i);
                if (isset($receiptItemData['receipt_id']) && isset($receiptItemData['amount'])) {
                    $receiptItem=ReceiptItem::create($receiptItemData);
                }
                // dd($receiptItemData);
            }
            
            
            if ($request->printOn==1) {
                $receiptItem=isset($receipt->getReceiptItem)?$receipt->getReceiptItem:null;
                return view('admin.templateMaker.receipt.show', compact('receipt','receiptItem'));
            }else{
                return redirect()->back()->with('message', 'Successfully receiptItem completed!');
            }
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\ReceiptItem  $receiptItem
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $receipt = Receipt::findOrFail($id);
            $receiptItem=isset($receipt->getReceiptItem)?$receipt->getReceiptItem:null;
            return view('admin.templateMaker.receipt.show', compact('receipt','receiptItem'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\ReceiptItem  $receiptItem
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            $receiptItem = ReceiptItem::findOrFail($id);
            return view('admin.templateMaker.receipt.edit', compact('receiptItem'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\ReceiptItem  $receiptItem
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        // if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
        //     $this->validate($request, [
        //         'title' => 'required|max:50',
        //     ]);
        //     $requestData = $request->all();
        //     $receiptItem = ReceiptItem::findOrFail($id);

        //     $receiptItem->update($requestData);

        //     return redirect()->back()->with('message', 'Successfully Mordality Updated!');
        // }else{
        //     $permission="'Update Level' permission needed!!!";
        //     return view('admin.notify.permission_denied', compact('permission'));
        // }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\ReceiptItem  $receiptItem
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            Receipt::destroy($id);
            return redirect('admin/TemplateMaker/receiptItem');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->sales_section)){
            Receipt::whereNotNull('id')->delete();
            ReceiptItem::whereNotNull('id')->delete();
            return redirect('admin/TemplateMaker/receiptItem');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
