<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\User;
use Illuminate\Support\Facades\Hash;
use Auth;
use Image;
use App\UserPermission;
use App\Profile;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $user_create = User::where('role_id', '>=', '1')->where('id', '>=', '2')->get();
            return view('admin.user_create.index', compact('user_create'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            return view('admin.user_create.create');
        }else{
            $permission="'Super Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $this->validate($request, [
                'name' => 'required|max:50|unique:users',
                'role_id' => 'required',
                'email' => 'required',
                'password' => 'required|min:6',
            ]);
            $requestData = $request->all();
            $requestData['password'] = Hash::make($request->password);
            $userId=User::create($requestData)->id;
            
            // create user permission
            $userPermission=array();
            $userPermission['user_id'] = $userId;
            UserPermission::create($userPermission);

            return redirect()->back()->with('message', 'Successfully User Created!');
        }else{
            $permission="'Super Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\User  $user_create
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            if ($id!=1 && $id!=2 || Auth::user()->getRole->slug=='owner') {
                $user_create = User::findOrFail($id);
                return view('admin.user_create.show', compact('user_create'));
            }else{
                return redirect()->back()->with('message', 'Owner can not access by admin!');
            }
        }elseif (Auth::user()->getRole->super_admin==1 && Auth::user()->getRole->slug=='owner') {
            $user_create = User::findOrFail($id);
            return view('admin.user_create.show', compact('user_create'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\User  $user_create
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            if ($id!=1 && $id!=2 || Auth::user()->getRole->slug=='owner') {
                $user_create = User::findOrFail($id);
                return view('admin.user_create.edit', compact('user_create'));
            }else{
                return redirect()->back()->with('message', 'Owner can not updated by admin!');
            }
        }elseif (Auth::user()->getRole->super_admin==1 && Auth::user()->getRole->slug=='owner') {
            $user_create = User::findOrFail($id);
                return view('admin.user_create.edit', compact('user_create'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\User  $user_create
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            if ($id!=1 && $id!=2 || Auth::user()->getRole->slug=='owner') {
                $this->validate($request, [
                    'name' => 'required|max:50',
                    'email' => 'required|email|max:50',
                ]);
                $requestData = $request->all();
                $user = User::findOrFail($id);
                // $requestData['password']=$user->password;

                $user->update($requestData);
                return redirect()->back()->with('message', 'Successfully Update User!');
            }else{
                return redirect()->back()->with('message', 'Owner can not updated by admin!');
            }
        }elseif (Auth::user()->getRole->super_admin==1 && Auth::user()->getRole->slug=='owner') {
            $this->validate($request, [
                'name' => 'required|max:50',
                'email' => 'required|email|max:50',
            ]);
            $requestData = $request->all();
            $user = User::findOrFail($id);
            // $requestData['password']=$user->password;

            $user->update($requestData);
            return redirect()->back()->with('message', 'Successfully Update User!');
        }else{
            $permission="'Owner Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\User  $user_create
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            if ($id!=1 && $id!=2) {
                // user delete
                User::destroy($id);

                // userPermission delete
                UserPermission::where('user_id', $id)->delete();
                return redirect()->back()->with('message', 'User deleted!');
            }else{
                return redirect()->back()->with('message', 'Owner can not delete!');
            }
        }else{
            $permission="'Super Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
