<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\UserLandingPage;
use Illuminate\Http\Request;

use Auth;
use App\UserPermission;

class UserLandingPageController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $user_landing_page = UserLandingPage::all();
            return view('admin.user_landing_page.index', compact('user_landing_page'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            return view('admin.user_landing_page.create');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->create==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $this->validate($request, [
                'user_id' => 'required',
            ]);
            $requestData = $request->all();
            UserLandingPage::create($requestData);
            return redirect()->back()->with('message', 'Successfully user_landing_page Added!');
        }else{
            $permission="'Create Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\UserLandingPage  $user_landing_page
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->read==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $user_landing_page = UserLandingPage::findOrFail($id);
            return view('admin.user_landing_page.show', compact('user_landing_page'));
        }else{
            $permission="'Read Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\UserLandingPage  $user_landing_page
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $user_landing_page = UserLandingPage::findOrFail($id);

            return view('admin.user_landing_page.edit', compact('user_landing_page'));
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\UserLandingPage  $user_landing_page
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->update==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $this->validate($request, [
                'user_id' => 'required',
            ]);
            $requestData = $request->all();
            $user_landing_page = UserLandingPage::findOrFail($id);
            $user_landing_page->update($requestData);

            return redirect()->back()->with('message', 'Successfully user_landing_page Updated!');
        }else{
            $permission="'Update Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\UserLandingPage  $user_landing_page
     * @return \Illuminate\Http\Response
     */
    
    public function destroy($id)
    {
        if(Auth::user()->getRole->admin==1 || Auth::user()->getRole->delete==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            UserLandingPage::destroy($id);
            return redirect('admin/user_landing_page');
        }else{
            $permission="'Delete Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    
    public function allDelete(){
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            UserLandingPage::whereNotNull('id')->delete();
            return redirect('admin/user_landing_page');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }
}
