<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\UserPermission;
use Illuminate\Http\Request;

use App\User;
use Auth;

class UserPermissionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $users=User::all();
            foreach ($users as $item) {
                UserPermission::firstOrCreate(['user_id' => $item->id]);
            }

            $user_permission = UserPermission::where('id', '>=', '2')->get();
            return view('admin.user_permission.index', compact('user_permission'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            return view('admin.user_permission.create');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $this->validate($request, [
                'user_id' => 'required|unique:user_permissions',
            ]);
            $requestData = $request->all();
            UserPermission::create($requestData);
            return redirect()->back()->with('message', 'Successfully Create Permission!');
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\UserPermission  $user_permission
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $user_permission = UserPermission::findOrFail($id);
            return view('admin.user_permission.show', compact('user_permission'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\UserPermission  $user_permission
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
            $user_permission = UserPermission::findOrFail($id);
            return view('admin.user_permission.edit', compact('user_permission'));
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\UserPermission  $user_permission
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){    
            if ($id!=1 && $id!=2) {
                $this->validate($request, [
                    'user_id' => 'required',
                ]);
                $requestData = $request->all();
                if($request->dashboard==null){
                    $requestData['dashboard']=$request->dashboard;
                }
                if($request->manage_user==null){
                    $requestData['manage_user']=$request->manage_user;
                }
                if($request->inventory==null){
                    $requestData['inventory']=$request->inventory;
                }
                if($request->sales_section==null){
                    $requestData['sales_section']=$request->sales_section;
                }
                if($request->purchase_section==null){
                    $requestData['purchase_section']=$request->purchase_section;
                }
                if($request->hrm==null){
                    $requestData['hrm']=$request->hrm;
                }
                if($request->register==null){
                    $requestData['register']=$request->register;
                }
                if($request->accounts==null){
                    $requestData['accounts']=$request->accounts;
                }
                if($request->bulk_upload==null){
                    $requestData['bulk_upload']=$request->bulk_upload;
                }
                if($request->buyer_request==null){
                    $requestData['buyer_request']=$request->buyer_request;
                }
                if($request->frontend==null){
                    $requestData['frontend']=$request->frontend;
                }
                if($request->reports==null){
                    $requestData['reports']=$request->reports;
                }
                if($request->disabled==null){
                    $requestData['disabled']=$request->disabled;
                }
                $user_permission = UserPermission::findOrFail($id);
                $user_permission->update($requestData);

                return redirect()->back()->with('message', 'Successfully Update Permission!');
            }else{
                return redirect()->back()->with('message', 'Owner Permission can not updated!');
            }    
        }else{
            $permission="'Admin Level' permission needed!!!";
            return view('admin.notify.permission_denied', compact('permission'));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\UserPermission  $user_permission
     * @return \Illuminate\Http\Response
     */
    // public function destroy($id)
    // {
    //     if(Auth::user()->getRole->admin==1 && isset(UserPermission::where('user_id', Auth::user()->id)->first()->manage_user)){
    //         if ($id!=1 && $id!=2) {
    //             UserPermission::destroy($id);
    //             return redirect()->back()->with('message', 'Permission deleted!');
    //         }else{
    //             return redirect()->back()->with('message', 'Default Permission can not delete!');
    //         }
    //     }else{
    //         $permission="'Admin Level' permission needed!!!";
    //         return view('admin.notify.permission_denied', compact('permission'));
    //     }
    // }
}
